{
****************************************************************
*  Name    : 18F258                                            *
*  Author  : David John Barker                                 *
*  Notice  : Copyright (c) 2015 Mecanique                      *
*          : All Rights Reserved                               *
*  Date    : 7/3/2015                                          *
****************************************************************
}

module SystemTypes

// system header...
#const _core = $0012                   // processor core
#const _ram_banks = $06                // 6 RAM bank(s) used
#variable _maxaccess = $60             // access ram is 96 bytes
#variable _maxram = $0600              // 1536 bytes of user RAM
#variable _maxrom = $008000            // 32 KB of program ROM
#const _eeprom = $0100                 // 256 bytes of EEPROM
#const _eeprom_start = $F00000         // EEPROM start address
#const _ports = $03                    // 3 available ports
#const _ccp = $01                      // 1 CCP module(s) available
#const _eccp = $00                     // ECCP module NOT supported
#const _mssp = $01                     // 1 MSSP module(s) available
#const _usart = $01                    // 1 USART(s) available
#const _adc = $05                      // 5 ADC channels available
#const _adres = $0A                    // 10 bit ADC resolution
#const _comparator = $00               // comparator module NOT supported
#const _psp = $00                      // Parallel Slave Port (PSP) is NOT supported
#const _can = $01                      // onboard CAN available
#const _usb = $00                      // USB is NOT supported
#const _ethernet = $00                 // onboard Ethernet is NOT supported
#const _flash_write = $01              // FLASH has write capability
#const _wdt_type = $00                 // WDT watchdog

// special function registers...
public system
   RXF0SIDH as byte absolute $0F00,
   RXF0SIDL as byte absolute $0F01,
   RXF0EIDH as byte absolute $0F02,
   RXF0EIDL as byte absolute $0F03,
   RXF1SIDH as byte absolute $0F04,
   RXF1SIDL as byte absolute $0F05,
   RXF1EIDH as byte absolute $0F06,
   RXF1EIDL as byte absolute $0F07,
   RXF2SIDH as byte absolute $0F08,
   RXF2SIDL as byte absolute $0F09,
   RXF2EIDH as byte absolute $0F0A,
   RXF2EIDL as byte absolute $0F0B,
   RXF3SIDH as byte absolute $0F0C,
   RXF3SIDL as byte absolute $0F0D,
   RXF3EIDH as byte absolute $0F0E,
   RXF3EIDL as byte absolute $0F0F,
   RXF4SIDH as byte absolute $0F10,
   RXF4SIDL as byte absolute $0F11,
   RXF4EIDH as byte absolute $0F12,
   RXF4EIDL as byte absolute $0F13,
   RXF5SIDH as byte absolute $0F14,
   RXF5SIDL as byte absolute $0F15,
   RXF5EIDH as byte absolute $0F16,
   RXF5EIDL as byte absolute $0F17,
   RXM0SIDH as byte absolute $0F18,
   RXM0SIDL as byte absolute $0F19,
   RXM0EIDH as byte absolute $0F1A,
   RXM0EIDL as byte absolute $0F1B,
   RXM1SIDH as byte absolute $0F1C,
   RXM1SIDL as byte absolute $0F1D,
   RXM1EIDH as byte absolute $0F1E,
   RXM1EIDL as byte absolute $0F1F,
   TXB2CON as byte absolute $0F20,
   TXB2SIDH as byte absolute $0F21,
   TXB2SIDL as byte absolute $0F22,
   TXB2EIDH as byte absolute $0F23,
   TXB2EIDL as byte absolute $0F24,
   TXB2DLC as byte absolute $0F25,
   TXB2D0 as byte absolute $0F26,
   TXB2D1 as byte absolute $0F27,
   TXB2D2 as byte absolute $0F28,
   TXB2D3 as byte absolute $0F29,
   TXB2D4 as byte absolute $0F2A,
   TXB2D5 as byte absolute $0F2B,
   TXB2D6 as byte absolute $0F2C,
   TXB2D7 as byte absolute $0F2D,
   CANSTATRO4 as byte absolute $0F2E,
   TXB1CON as byte absolute $0F30,
   TXB1SIDH as byte absolute $0F31,
   TXB1SIDL as byte absolute $0F32,
   TXB1EIDH as byte absolute $0F33,
   TXB1EIDL as byte absolute $0F34,
   TXB1DLC as byte absolute $0F35,
   TXB1D0 as byte absolute $0F36,
   TXB1D1 as byte absolute $0F37,
   TXB1D2 as byte absolute $0F38,
   TXB1D3 as byte absolute $0F39,
   TXB1D4 as byte absolute $0F3A,
   TXB1D5 as byte absolute $0F3B,
   TXB1D6 as byte absolute $0F3C,
   TXB1D7 as byte absolute $0F3D,
   CANSTATRO3 as byte absolute $0F3E,
   TXB0CON as byte absolute $0F40,
   TXB0SIDH as byte absolute $0F41,
   TXB0SIDL as byte absolute $0F42,
   TXB0EIDH as byte absolute $0F43,
   TXB0EIDL as byte absolute $0F44,
   TXB0DLC as byte absolute $0F45,
   TXB0D0 as byte absolute $0F46,
   TXB0D1 as byte absolute $0F47,
   TXB0D2 as byte absolute $0F48,
   TXB0D3 as byte absolute $0F49,
   TXB0D4 as byte absolute $0F4A,
   TXB0D5 as byte absolute $0F4B,
   TXB0D6 as byte absolute $0F4C,
   TXB0D7 as byte absolute $0F4D,
   CANSTATRO2 as byte absolute $0F4E,
   RXB1CON as byte absolute $0F50,
   RXB1SIDH as byte absolute $0F51,
   RXB1SIDL as byte absolute $0F52,
   RXB1EIDH as byte absolute $0F53,
   RXB1EIDL as byte absolute $0F54,
   RXB1DLC as byte absolute $0F55,
   RXB1D0 as byte absolute $0F56,
   RXB1D1 as byte absolute $0F57,
   RXB1D2 as byte absolute $0F58,
   RXB1D3 as byte absolute $0F59,
   RXB1D4 as byte absolute $0F5A,
   RXB1D5 as byte absolute $0F5B,
   RXB1D6 as byte absolute $0F5C,
   RXB1D7 as byte absolute $0F5D,
   CANSTATRO1 as byte absolute $0F5E,
   RXB0CON as byte absolute $0F60,
   RXB0SIDH as byte absolute $0F61,
   RXB0SIDL as byte absolute $0F62,
   RXB0EIDH as byte absolute $0F63,
   RXB0EIDL as byte absolute $0F64,
   RXB0DLC as byte absolute $0F65,
   RXB0D0 as byte absolute $0F66,
   RXB0D1 as byte absolute $0F67,
   RXB0D2 as byte absolute $0F68,
   RXB0D3 as byte absolute $0F69,
   RXB0D4 as byte absolute $0F6A,
   RXB0D5 as byte absolute $0F6B,
   RXB0D6 as byte absolute $0F6C,
   RXB0D7 as byte absolute $0F6D,
   CANSTAT as byte absolute $0F6E,
   CANCON as byte absolute $0F6F,
   BRGCON1 as byte absolute $0F70,
   BRGCON2 as byte absolute $0F71,
   BRGCON3 as byte absolute $0F72,
   CIOCON as byte absolute $0F73,
   COMSTAT as byte absolute $0F74,
   RXERRCNT as byte absolute $0F75,
   TXERRCNT as byte absolute $0F76,
   LATA as byte absolute $0F89,
   LATB as byte absolute $0F8A,
   LATC as byte absolute $0F8B,
   DDRA as byte absolute $0F92,
   TRISA as byte absolute $0F92,
   DDRB as byte absolute $0F93,
   TRISB as byte absolute $0F93,
   DDRC as byte absolute $0F94,
   TRISC as byte absolute $0F94,
   PIE1 as byte absolute $0F9D,
   PIR1 as byte absolute $0F9E,
   IPR1 as byte absolute $0F9F,
   PIE2 as byte absolute $0FA0,
   PIR2 as byte absolute $0FA1,
   IPR2 as byte absolute $0FA2,
   PIE3 as byte absolute $0FA3,
   PIR3 as byte absolute $0FA4,
   IPR3 as byte absolute $0FA5,
   EECON1 as byte absolute $0FA6,
   EECON2 as byte absolute $0FA7,
   EEDATA as byte absolute $0FA8,
   EEADR as byte absolute $0FA9,
   RCSTA as byte absolute $0FAB,
   TXSTA as byte absolute $0FAC,
   TXREG as byte absolute $0FAD,
   RCREG as byte absolute $0FAE,
   SPBRG as byte absolute $0FAF,
   T3CON as byte absolute $0FB1,
   TMR3 as byte absolute $0FB2,
   TMR3L as byte absolute $0FB2,
   TMR3H as byte absolute $0FB3,
   CCP1CON as byte absolute $0FBD,
   CCPR1 as byte absolute $0FBE,
   CCPR1L as byte absolute $0FBE,
   CCPR1H as byte absolute $0FBF,
   ADCON1 as byte absolute $0FC1,
   ADCON0 as byte absolute $0FC2,
   ADRES as byte absolute $0FC3,
   ADRESL as byte absolute $0FC3,
   ADRESH as byte absolute $0FC4,
   SSPCON2 as byte absolute $0FC5,
   SSPCON1 as byte absolute $0FC6,
   SSPSTAT as byte absolute $0FC7,
   SSPADD as byte absolute $0FC8,
   SSPBUF as byte absolute $0FC9,
   T2CON as byte absolute $0FCA,
   PR2 as byte absolute $0FCB,
   TMR2 as byte absolute $0FCC,
   T1CON as byte absolute $0FCD,
   TMR1 as byte absolute $0FCE,
   TMR1L as byte absolute $0FCE,
   TMR1H as byte absolute $0FCF,
   RCON as byte absolute $0FD0,
   WDTCON as byte absolute $0FD1,
   LVDCON as byte absolute $0FD2,
   OSCCON as byte absolute $0FD3,
   T0CON as byte absolute $0FD5,
   TMR0 as byte absolute $0FD6,
   TMR0L as byte absolute $0FD6,
   TMR0H as byte absolute $0FD7,
   STATUS as byte absolute $0FD8,
   FSR2L as byte absolute $0FD9,
   FSR2H as byte absolute $0FDA,
   PLUSW2 as byte absolute $0FDB,
   PREINC2 as byte absolute $0FDC,
   POSTDEC2 as byte absolute $0FDD,
   POSTINC2 as byte absolute $0FDE,
   INDF2 as byte absolute $0FDF,
   BSR as byte absolute $0FE0,
   FSR1L as byte absolute $0FE1,
   FSR1H as byte absolute $0FE2,
   PLUSW1 as byte absolute $0FE3,
   PREINC1 as byte absolute $0FE4,
   POSTDEC1 as byte absolute $0FE5,
   POSTINC1 as byte absolute $0FE6,
   INDF1 as byte absolute $0FE7,
   WREG as byte absolute $0FE8,
   FSR0L as byte absolute $0FE9,
   FSR0H as byte absolute $0FEA,
   PLUSW0 as byte absolute $0FEB,
   PREINC0 as byte absolute $0FEC,
   POSTDEC0 as byte absolute $0FED,
   POSTINC0 as byte absolute $0FEE,
   INDF0 as byte absolute $0FEF,
   INTCON3 as byte absolute $0FF0,
   INTCON2 as byte absolute $0FF1,
   INTCON as byte absolute $0FF2,
   INTCON1 as byte absolute $0FF2,
   PRODL as byte absolute $0FF3,
   PRODH as byte absolute $0FF4,
   TABLAT as byte absolute $0FF5,
   TBLPTR as byte absolute $0FF6,
   TBLPTRL as byte absolute $0FF6,
   TBLPTRH as byte absolute $0FF7,
   TBLPTRU as byte absolute $0FF8,
   PC as byte absolute $0FF9,
   PCL as byte absolute $0FF9,
   PCLATH as byte absolute $0FFA,
   PCLATU as byte absolute $0FFB,
   STKPTR as byte absolute $0FFC,
   TOS as byte absolute $0FFD,
   TOSL as byte absolute $0FFD,
   TOSH as byte absolute $0FFE,
   TOSU as byte absolute $0FFF

// system ports...
public system port
   PORTA as byte absolute $0F80,
   PORTB as byte absolute $0F81,
   PORTC as byte absolute $0F82

// alias...
public dim
   PROD as PRODL.AsWord,
   FSR0 as FSR0L.AsWord,
   FSR1 as FSR1L.AsWord,
   FSR2 as FSR2L.AsWord,
   TABLEPTR as TBLPTRL.AsWord

// configuration fuses...
public config
   OSC(OSC) = [LP, XT, HS, RC, EC, ECIO, HSPLL, RCIO],
   OSCS(OSCS) = [ON, OFF],
   PWRT(PWRT) = [ON, OFF],
   BOR(BOR) = [OFF, ON],
   BORV(BORV) = [45, 42, 27, 25],
   WDT(WDT) = [OFF, ON],
   WDTPS(WDTPS) = [1, 2, 4, 8, 16, 32, 64, 128],
   STVR(STVR) = [OFF, ON],
   LVP(LVP) = [OFF, ON],
   DEBUG(DEBUG) = [ON, OFF],
   CP0(CP0) = [ON, OFF],
   CP1(CP1) = [ON, OFF],
   CP2(CP2) = [ON, OFF],
   CP3(CP3) = [ON, OFF],
   CPB(CPB) = [ON, OFF],
   CPD(CPD) = [ON, OFF],
   WRT0(WRT0) = [ON, OFF],
   WRT1(WRT1) = [ON, OFF],
   WRT2(WRT2) = [ON, OFF],
   WRT3(WRT3) = [ON, OFF],
   WRTC(WRTC) = [ON, OFF],
   WRTB(WRTB) = [ON, OFF],
   WRTD(WRTD) = [ON, OFF],
   EBTR0(EBTR0) = [ON, OFF],
   EBTR1(EBTR1) = [ON, OFF],
   EBTR2(EBTR2) = [ON, OFF],
   EBTR3(EBTR3) = [ON, OFF],
   EBTRB(EBTRB) = [ON, OFF]

// default fuses...
config
   OSC = HS,
   OSCS = OFF,
   PWRT = ON,
   BOR = ON,
   BORV = 25,
   WDT = OFF,
   WDTPS = 128,
   STVR = ON,
   LVP = OFF,
   DEBUG = OFF
