{
****************************************************************
*  Name    : 18F4431                                           *
*  Author  : David John Barker                                 *
*  Notice  : Copyright (c) 2015 Mecanique                      *
*          : All Rights Reserved                               *
*  Date    : 7/3/2015                                          *
****************************************************************
}

module SystemTypes

// system header...
#const _core = $0012                   // processor core
#const _ram_banks = $03                // 3 RAM bank(s) used
#variable _maxaccess = $60             // access ram is 96 bytes
#variable _maxram = $0300              // 768 bytes of user RAM
#variable _maxrom = $004000            // 16 KB of program ROM
#const _eeprom = $0100                 // 256 bytes of EEPROM
#const _eeprom_start = $F00000         // EEPROM start address
#const _ports = $05                    // 5 available ports
#const _ccp = $02                      // 2 CCP module(s) available
#const _eccp = $00                     // ECCP module NOT supported
#const _mssp = $01                     // 1 MSSP module(s) available
#const _usart = $01                    // 1 USART(s) available
#const _adc = $06                      // 6 ADC channels available
#const _adres = $0A                    // 10 bit ADC resolution
#const _comparator = $00               // comparator module NOT supported
#const _psp = $00                      // Parallel Slave Port (PSP) is NOT supported
#const _can = $00                      // onboard CAN is NOT supported
#const _usb = $00                      // USB is NOT supported
#const _ethernet = $00                 // onboard Ethernet is NOT supported
#const _flash_write = $01              // FLASH has write capability
#const _wdt_type = $01                 // WDTEN watchdog

// special function registers...
public system
   DFLTCON as byte absolute $0F60,
   CAP3CON as byte absolute $0F61,
   CAP2CON as byte absolute $0F62,
   CAP1CON as byte absolute $0F63,
   CAP3BUFL as byte absolute $0F64,
   MAXCNTL as byte absolute $0F64,
   CAP3BUFH as byte absolute $0F65,
   MAXCNTH as byte absolute $0F65,
   CAP2BUFL as byte absolute $0F66,
   POSCNTL as byte absolute $0F66,
   CAP2BUFH as byte absolute $0F67,
   POSCNTH as byte absolute $0F67,
   CAP1BUFL as byte absolute $0F68,
   VELRL as byte absolute $0F68,
   CAP1BUFH as byte absolute $0F69,
   VELRH as byte absolute $0F69,
   OVDCONS as byte absolute $0F6A,
   OVDCOND as byte absolute $0F6B,
   FLTCONFIG as byte absolute $0F6C,
   DTCON as byte absolute $0F6D,
   PWMCON1 as byte absolute $0F6E,
   PWMCON0 as byte absolute $0F6F,
   SEVTCMPH as byte absolute $0F70,
   SEVTCMPL as byte absolute $0F71,
   PDC3H as byte absolute $0F72,
   PDC3L as byte absolute $0F73,
   PDC2H as byte absolute $0F74,
   PDC2L as byte absolute $0F75,
   PDC1H as byte absolute $0F76,
   PDC1L as byte absolute $0F77,
   PDC0H as byte absolute $0F78,
   PDC0L as byte absolute $0F79,
   PTPERH as byte absolute $0F7A,
   PTPERL as byte absolute $0F7B,
   PTMRH as byte absolute $0F7C,
   PTMRL as byte absolute $0F7D,
   PTCON1 as byte absolute $0F7E,
   PTCON0 as byte absolute $0F7F,
   TMR5 as byte absolute $0F87,
   TMR5L as byte absolute $0F87,
   TMR5H as byte absolute $0F88,
   LATA as byte absolute $0F89,
   LATB as byte absolute $0F8A,
   LATC as byte absolute $0F8B,
   LATD as byte absolute $0F8C,
   LATE as byte absolute $0F8D,
   PR5 as byte absolute $0F90,
   PR5L as byte absolute $0F90,
   PR5H as byte absolute $0F91,
   DDRA as byte absolute $0F92,
   TRISA as byte absolute $0F92,
   DDRB as byte absolute $0F93,
   TRISB as byte absolute $0F93,
   DDRC as byte absolute $0F94,
   TRISC as byte absolute $0F94,
   DDRD as byte absolute $0F95,
   TRISD as byte absolute $0F95,
   DDRE as byte absolute $0F96,
   TRISE as byte absolute $0F96,
   ADCHS as byte absolute $0F99,
   ADCON3 as byte absolute $0F9A,
   OSCTUNE as byte absolute $0F9B,
   PIE1 as byte absolute $0F9D,
   PIR1 as byte absolute $0F9E,
   IPR1 as byte absolute $0F9F,
   PIE2 as byte absolute $0FA0,
   PIR2 as byte absolute $0FA1,
   IPR2 as byte absolute $0FA2,
   PIE3 as byte absolute $0FA3,
   PIR3 as byte absolute $0FA4,
   IPR3 as byte absolute $0FA5,
   EECON1 as byte absolute $0FA6,
   EECON2 as byte absolute $0FA7,
   EEDATA as byte absolute $0FA8,
   EEADR as byte absolute $0FA9,
   BAUDCON as byte absolute $0FAA,
   BAUDCTL as byte absolute $0FAA,
   RCSTA as byte absolute $0FAB,
   TXSTA as byte absolute $0FAC,
   TXREG as byte absolute $0FAD,
   RCREG as byte absolute $0FAE,
   SPBRG as byte absolute $0FAF,
   SPBRGH as byte absolute $0FB0,
   QEICON as byte absolute $0FB6,
   T5CON as byte absolute $0FB7,
   ANSEL0 as byte absolute $0FB8,
   ANSEL1 as byte absolute $0FB9,
   CCP2CON as byte absolute $0FBA,
   CCPR2 as byte absolute $0FBB,
   CCPR2L as byte absolute $0FBB,
   CCPR2H as byte absolute $0FBC,
   CCP1CON as byte absolute $0FBD,
   CCPR1 as byte absolute $0FBE,
   CCPR1L as byte absolute $0FBE,
   CCPR1H as byte absolute $0FBF,
   ADCON2 as byte absolute $0FC0,
   ADCON1 as byte absolute $0FC1,
   ADCON0 as byte absolute $0FC2,
   ADRES as byte absolute $0FC3,
   ADRESL as byte absolute $0FC3,
   ADRESH as byte absolute $0FC4,
   SSPCON as byte absolute $0FC6,
   SSPSTAT as byte absolute $0FC7,
   SSPADD as byte absolute $0FC8,
   SSPBUF as byte absolute $0FC9,
   T2CON as byte absolute $0FCA,
   PR2 as byte absolute $0FCB,
   TMR2 as byte absolute $0FCC,
   T1CON as byte absolute $0FCD,
   TMR1 as byte absolute $0FCE,
   TMR1L as byte absolute $0FCE,
   TMR1H as byte absolute $0FCF,
   RCON as byte absolute $0FD0,
   WDTCON as byte absolute $0FD1,
   LVDCON as byte absolute $0FD2,
   OSCCON as byte absolute $0FD3,
   T0CON as byte absolute $0FD5,
   TMR0 as byte absolute $0FD6,
   TMR0L as byte absolute $0FD6,
   TMR0H as byte absolute $0FD7,
   STATUS as byte absolute $0FD8,
   FSR2L as byte absolute $0FD9,
   FSR2H as byte absolute $0FDA,
   PLUSW2 as byte absolute $0FDB,
   PREINC2 as byte absolute $0FDC,
   POSTDEC2 as byte absolute $0FDD,
   POSTINC2 as byte absolute $0FDE,
   INDF2 as byte absolute $0FDF,
   BSR as byte absolute $0FE0,
   FSR1L as byte absolute $0FE1,
   FSR1H as byte absolute $0FE2,
   PLUSW1 as byte absolute $0FE3,
   PREINC1 as byte absolute $0FE4,
   POSTDEC1 as byte absolute $0FE5,
   POSTINC1 as byte absolute $0FE6,
   INDF1 as byte absolute $0FE7,
   WREG as byte absolute $0FE8,
   FSR0L as byte absolute $0FE9,
   FSR0H as byte absolute $0FEA,
   PLUSW0 as byte absolute $0FEB,
   PREINC0 as byte absolute $0FEC,
   POSTDEC0 as byte absolute $0FED,
   POSTINC0 as byte absolute $0FEE,
   INDF0 as byte absolute $0FEF,
   INTCON3 as byte absolute $0FF0,
   INTCON2 as byte absolute $0FF1,
   INTCON as byte absolute $0FF2,
   PRODL as byte absolute $0FF3,
   PRODH as byte absolute $0FF4,
   TABLAT as byte absolute $0FF5,
   TBLPTR as byte absolute $0FF6,
   TBLPTRL as byte absolute $0FF6,
   TBLPTRH as byte absolute $0FF7,
   TBLPTRU as byte absolute $0FF8,
   PC as byte absolute $0FF9,
   PCL as byte absolute $0FF9,
   PCLATH as byte absolute $0FFA,
   PCLATU as byte absolute $0FFB,
   STKPTR as byte absolute $0FFC,
   TOS as byte absolute $0FFD,
   TOSL as byte absolute $0FFD,
   TOSH as byte absolute $0FFE,
   TOSU as byte absolute $0FFF

// system ports...
public system port
   PORTA as byte absolute $0F80,
   PORTB as byte absolute $0F81,
   PORTC as byte absolute $0F82,
   PORTD as byte absolute $0F83,
   PORTE as byte absolute $0F84

// alias...
public dim
   PROD as PRODL.AsWord,
   FSR0 as FSR0L.AsWord,
   FSR1 as FSR1L.AsWord,
   FSR2 as FSR2L.AsWord,
   TABLEPTR as TBLPTRL.AsWord

// configuration fuses...
public config
   OSC(OSC) = [LP, XT, HS, RC2, EC, ECIO, HSPLL, RCIO, IRCIO, IRC, RC1, RC],
   FCMEN(FCMEN) = [OFF, ON],
   IESO(IESO) = [OFF, ON],
   PWRTEN(PWRTEN) = [ON, OFF],
   BOREN(BOREN) = [OFF, ON],
   BORV(BORV) = [45, 42, 27, 20],
   WDTEN(WDTEN) = [OFF, ON],
   WDPS(WDPS) = [1, 2, 4, 8, 16, 32, 64, 128, 256, 512, 1024, 2048, 4096, 8192, 16384, 32768],
   WINEN(WINEN) = [ON, OFF],
   PWMPIN(PWMPIN) = [ON, OFF],
   LPOL(LPOL) = [LOW, HIGH],
   HPOL(HPOL) = [LOW, HIGH],
   T1OSCMX(T1OSCMX) = [OFF, ON],
   FLTAMX(FLTAMX) = [RD4, RC1],
   SSPMX(SSPMX) = [RD1, RC7],
   PWM4MX(PWM4MX) = [RD5, RB5],
   EXCLKMX(EXCLKMX) = [RD0, RC3],
   MCLRE(MCLRE) = [OFF, ON],
   STVREN(STVREN) = [OFF, ON],
   LVP(LVP) = [OFF, ON],
   DEBUG(DEBUG) = [ON, OFF],
   CP0(CP0) = [ON, OFF],
   CP1(CP1) = [ON, OFF],
   CP2(CP2) = [ON, OFF],
   CP3(CP3) = [ON, OFF],
   CPB(CPB) = [ON, OFF],
   CPD(CPD) = [ON, OFF],
   WRT0(WRT0) = [ON, OFF],
   WRT1(WRT1) = [ON, OFF],
   WRT2(WRT2) = [ON, OFF],
   WRT3(WRT3) = [ON, OFF],
   WRTC(WRTC) = [ON, OFF],
   WRTB(WRTB) = [ON, OFF],
   WRTD(WRTD) = [ON, OFF],
   EBTR0(EBTR0) = [ON, OFF],
   EBTR1(EBTR1) = [ON, OFF],
   EBTR2(EBTR2) = [ON, OFF],
   EBTR3(EBTR3) = [ON, OFF],
   EBTRB(EBTRB) = [ON, OFF]

// default fuses...
config
   OSC = HS,
   FCMEN = OFF,
   IESO = OFF,
   BOREN = ON,
   BORV = 20,
   WDTEN = OFF,
   STVREN = ON,
   LVP = OFF,
   DEBUG = OFF
