{
****************************************************************
*  Name    : 18F44J10                                          *
*  Author  : David John Barker                                 *
*  Notice  : Copyright (c) 2015 Mecanique                      *
*          : All Rights Reserved                               *
*  Date    : 7/3/2015                                          *
****************************************************************
}

module SystemTypes

// system header...
#const _core = $0012                   // processor core
#const _ram_banks = $04                // 4 RAM bank(s) used
#variable _maxaccess = $80             // access ram is 128 bytes
#variable _maxram = $0400              // 1024 bytes of user RAM
#variable _maxrom = $003FF8            // 15 KB of program ROM
#const _eeprom = $0000                 // 0 bytes of EEPROM
#const _eeprom_start = $F00000         // EEPROM start address
#const _ports = $05                    // 5 available ports
#const _ccp = $01                      // 1 CCP module(s) available
#const _eccp = $01                     // 1 ECCP module(s) available
#const _mssp = $02                     // 2 MSSP module(s) available
#const _usart = $01                    // 1 USART(s) available
#const _adc = $0D                      // 13 ADC channels available
#const _adres = $0A                    // 10 bit ADC resolution
#const _comparator = $02               // 2 comparator(s) available
#const _psp = $01                      // onboard Parallel Slave Port (PSP) available
#const _can = $00                      // onboard CAN is NOT supported
#const _usb = $00                      // USB is NOT supported
#const _ethernet = $00                 // onboard Ethernet is NOT supported
#const _flash_write = $01              // FLASH has write capability
#const _wdt_type = $01                 // WDTEN watchdog

// special function registers...
public system
   SSP2CON2 as byte absolute $0F85,
   SSP2CON1 as byte absolute $0F86,
   SSP2STAT as byte absolute $0F87,
   SSP2ADD as byte absolute $0F88,
   LATA as byte absolute $0F89,
   LATB as byte absolute $0F8A,
   LATC as byte absolute $0F8B,
   LATD as byte absolute $0F8C,
   LATE as byte absolute $0F8D,
   SSP2BUF as byte absolute $0F8E,
   DDRA as byte absolute $0F92,
   TRISA as byte absolute $0F92,
   DDRB as byte absolute $0F93,
   TRISB as byte absolute $0F93,
   DDRC as byte absolute $0F94,
   TRISC as byte absolute $0F94,
   DDRD as byte absolute $0F95,
   TRISD as byte absolute $0F95,
   DDRE as byte absolute $0F96,
   TRISE as byte absolute $0F96,
   OSCTUNE as byte absolute $0F9B,
   PIE1 as byte absolute $0F9D,
   PIR1 as byte absolute $0F9E,
   IPR1 as byte absolute $0F9F,
   PIE2 as byte absolute $0FA0,
   PIR2 as byte absolute $0FA1,
   IPR2 as byte absolute $0FA2,
   PIE3 as byte absolute $0FA3,
   PIR3 as byte absolute $0FA4,
   IPR3 as byte absolute $0FA5,
   EECON1 as byte absolute $0FA6,
   EECON2 as byte absolute $0FA7,
   RCSTA as byte absolute $0FAB,
   RCSTA1 as byte absolute $0FAB,
   TXSTA as byte absolute $0FAC,
   TXSTA1 as byte absolute $0FAC,
   TXREG as byte absolute $0FAD,
   TXREG1 as byte absolute $0FAD,
   RCREG as byte absolute $0FAE,
   RCREG1 as byte absolute $0FAE,
   SPBRG as byte absolute $0FAF,
   SPBRG1 as byte absolute $0FAF,
   SPBRGH as byte absolute $0FB0,
   CMCON as byte absolute $0FB4,
   CVRCON as byte absolute $0FB5,
   ECCP1AS as byte absolute $0FB6,
   ECCP1DEL as byte absolute $0FB7,
   PWM1CON as byte absolute $0FB7,
   BAUDCON as byte absolute $0FB8,
   BAUDCTL as byte absolute $0FB8,
   CCP2CON as byte absolute $0FBA,
   CCPR2 as byte absolute $0FBB,
   CCPR2L as byte absolute $0FBB,
   CCPR2H as byte absolute $0FBC,
   CCP1CON as byte absolute $0FBD,
   ECCP1CON as byte absolute $0FBD,
   CCPR1 as byte absolute $0FBE,
   CCPR1L as byte absolute $0FBE,
   CCPR1H as byte absolute $0FBF,
   ADCON2 as byte absolute $0FC0,
   ADCON1 as byte absolute $0FC1,
   ADCON0 as byte absolute $0FC2,
   ADRES as byte absolute $0FC3,
   ADRESL as byte absolute $0FC3,
   ADRESH as byte absolute $0FC4,
   SSP1CON2 as byte absolute $0FC5,
   SSPCON2 as byte absolute $0FC5,
   SSP1CON1 as byte absolute $0FC6,
   SSPCON1 as byte absolute $0FC6,
   SSP1STAT as byte absolute $0FC7,
   SSPSTAT as byte absolute $0FC7,
   SSP1ADD as byte absolute $0FC8,
   SSPADD as byte absolute $0FC8,
   SSP1BUF as byte absolute $0FC9,
   SSPBUF as byte absolute $0FC9,
   T2CON as byte absolute $0FCA,
   PR2 as byte absolute $0FCB,
   TMR2 as byte absolute $0FCC,
   T1CON as byte absolute $0FCD,
   TMR1 as byte absolute $0FCE,
   TMR1L as byte absolute $0FCE,
   TMR1H as byte absolute $0FCF,
   RCON as byte absolute $0FD0,
   WDTCON as byte absolute $0FD1,
   OSCCON as byte absolute $0FD3,
   T0CON as byte absolute $0FD5,
   TMR0 as byte absolute $0FD6,
   TMR0L as byte absolute $0FD6,
   TMR0H as byte absolute $0FD7,
   STATUS as byte absolute $0FD8,
   FSR2L as byte absolute $0FD9,
   FSR2H as byte absolute $0FDA,
   PLUSW2 as byte absolute $0FDB,
   PREINC2 as byte absolute $0FDC,
   POSTDEC2 as byte absolute $0FDD,
   POSTINC2 as byte absolute $0FDE,
   INDF2 as byte absolute $0FDF,
   BSR as byte absolute $0FE0,
   FSR1L as byte absolute $0FE1,
   FSR1H as byte absolute $0FE2,
   PLUSW1 as byte absolute $0FE3,
   PREINC1 as byte absolute $0FE4,
   POSTDEC1 as byte absolute $0FE5,
   POSTINC1 as byte absolute $0FE6,
   INDF1 as byte absolute $0FE7,
   WREG as byte absolute $0FE8,
   FSR0L as byte absolute $0FE9,
   FSR0H as byte absolute $0FEA,
   PLUSW0 as byte absolute $0FEB,
   PREINC0 as byte absolute $0FEC,
   POSTDEC0 as byte absolute $0FED,
   POSTINC0 as byte absolute $0FEE,
   INDF0 as byte absolute $0FEF,
   INTCON3 as byte absolute $0FF0,
   INTCON2 as byte absolute $0FF1,
   INTCON as byte absolute $0FF2,
   PRODL as byte absolute $0FF3,
   PRODH as byte absolute $0FF4,
   TABLAT as byte absolute $0FF5,
   TBLPTR as byte absolute $0FF6,
   TBLPTRL as byte absolute $0FF6,
   TBLPTRH as byte absolute $0FF7,
   TBLPTRU as byte absolute $0FF8,
   PC as byte absolute $0FF9,
   PCL as byte absolute $0FF9,
   PCLATH as byte absolute $0FFA,
   PCLATU as byte absolute $0FFB,
   STKPTR as byte absolute $0FFC,
   TOS as byte absolute $0FFD,
   TOSL as byte absolute $0FFD,
   TOSH as byte absolute $0FFE,
   TOSU as byte absolute $0FFF

// system ports...
public system port
   PORTA as byte absolute $0F80,
   PORTB as byte absolute $0F81,
   PORTC as byte absolute $0F82,
   PORTD as byte absolute $0F83,
   PORTE as byte absolute $0F84

// alias...
public dim
   PROD as PRODL.AsWord,
   FSR0 as FSR0L.AsWord,
   FSR1 as FSR1L.AsWord,
   FSR2 as FSR2L.AsWord,
   TABLEPTR as TBLPTRL.AsWord

// configuration fuses...
public config
   WDTEN(WDTEN) = [OFF, ON],
   STVREN(STVREN) = [OFF, ON],
   XINST(XINST) = [OFF, ON],
   DEBUG(DEBUG) = [ON, OFF],
   CP0(CP0) = [ON, OFF],
   FOSC(FOSC) = [HS, HSPLL, EC, ECPLL],
   FOSC2(FOSC2) = [OFF, ON],
   FCMEN(FCMEN) = [OFF, ON],
   IESO(IESO) = [OFF, ON],
   WDTPS(WDTPS) = [1, 2, 4, 8, 16, 32, 64, 128, 256, 512, 1024, 2048, 4096, 8192, 16384, 32768],
   CCP2MX(CCP2MX) = [ALTERNATE, DEFAULT]

// default fuses...
config
   WDTEN = OFF,
   STVREN = ON,
   XINST = OFF,
   DEBUG = OFF,
   FOSC = HS,
   FOSC2 = ON,
   FCMEN = OFF,
   IESO = OFF,
   WDTPS = 128
