{
****************************************************************
*  Name    : 18F6680                                           *
*  Author  : David John Barker                                 *
*  Notice  : Copyright (c) 2015 Mecanique                      *
*          : All Rights Reserved                               *
*  Date    : 7/3/2015                                          *
****************************************************************
}

module SystemTypes

// system header...
#const _core = $0012                   // processor core
#const _ram_banks = $0D                // 13 RAM bank(s) used
#variable _maxaccess = $60             // access ram is 96 bytes
#variable _maxram = $0D00              // 3328 bytes of user RAM
#variable _maxrom = $010000            // 64 KB of program ROM
#const _eeprom = $0400                 // 1024 bytes of EEPROM
#const _eeprom_start = $F00000         // EEPROM start address
#const _ports = $07                    // 7 available ports
#const _ccp = $01                      // 1 CCP module(s) available
#const _eccp = $01                     // 1 ECCP module(s) available
#const _mssp = $01                     // 1 MSSP module(s) available
#const _usart = $01                    // 1 USART(s) available
#const _adc = $0C                      // 12 ADC channels available
#const _adres = $0A                    // 10 bit ADC resolution
#const _comparator = $02               // 2 comparator(s) available
#const _psp = $01                      // onboard Parallel Slave Port (PSP) available
#const _can = $01                      // onboard CAN available
#const _usb = $00                      // USB is NOT supported
#const _ethernet = $00                 // onboard Ethernet is NOT supported
#const _flash_write = $01              // FLASH has write capability
#const _wdt_type = $00                 // WDT watchdog

// special function registers...
public system
   RXF6SIDH as byte absolute $0D60,
   RXF6SIDL as byte absolute $0D61,
   RXF6EIDH as byte absolute $0D62,
   RXF6EIDL as byte absolute $0D63,
   RXF7SIDH as byte absolute $0D64,
   RXF7SIDL as byte absolute $0D65,
   RXF7EIDH as byte absolute $0D66,
   RXF7EIDL as byte absolute $0D67,
   RXF8SIDH as byte absolute $0D68,
   RXF8SIDL as byte absolute $0D69,
   RXF8EIDH as byte absolute $0D6A,
   RXF8EIDL as byte absolute $0D6B,
   RXF9SIDH as byte absolute $0D70,
   RXF9SIDL as byte absolute $0D71,
   RXF9EIDH as byte absolute $0D72,
   RXF9EIDL as byte absolute $0D73,
   RXF10SIDH as byte absolute $0D74,
   RXF10SIDL as byte absolute $0D75,
   RXF10EIDH as byte absolute $0D76,
   RXF10EIDL as byte absolute $0D77,
   RXF11SIDH as byte absolute $0D78,
   RXF11SIDL as byte absolute $0D79,
   RXF11EIDH as byte absolute $0D7A,
   RXF11EIDL as byte absolute $0D7B,
   RXF12SIDH as byte absolute $0D80,
   RXF12SIDL as byte absolute $0D81,
   RXF12EIDH as byte absolute $0D82,
   RXF12EIDL as byte absolute $0D83,
   RXF13SIDH as byte absolute $0D84,
   RXF13SIDL as byte absolute $0D85,
   RXF13EIDH as byte absolute $0D86,
   RXF13EIDL as byte absolute $0D87,
   RXF14SIDH as byte absolute $0D88,
   RXF14SIDL as byte absolute $0D89,
   RXF14EIDH as byte absolute $0D8A,
   RXF14EIDL as byte absolute $0D8B,
   RXF15SIDH as byte absolute $0D90,
   RXF15SIDL as byte absolute $0D91,
   RXF15EIDH as byte absolute $0D92,
   RXF15EIDL as byte absolute $0D93,
   RXFCON0 as byte absolute $0DD4,
   RXFCON1 as byte absolute $0DD5,
   SDFLC as byte absolute $0DD8,
   RXFBCON0 as byte absolute $0DE0,
   RXFBCON1 as byte absolute $0DE1,
   RXFBCON2 as byte absolute $0DE2,
   RXFBCON3 as byte absolute $0DE3,
   RXFBCON4 as byte absolute $0DE4,
   RXFBCON5 as byte absolute $0DE5,
   RXFBCON6 as byte absolute $0DE6,
   RXFBCON7 as byte absolute $0DE7,
   MSEL0 as byte absolute $0DF0,
   MSEL1 as byte absolute $0DF1,
   MSEL2 as byte absolute $0DF2,
   MSEL3 as byte absolute $0DF3,
   BSEL0 as byte absolute $0DF8,
   BIE0 as byte absolute $0DFA,
   TXBIE as byte absolute $0DFC,
   B0CON as byte absolute $0E20,
   B0SIDH as byte absolute $0E21,
   B0SIDL as byte absolute $0E22,
   B0EIDH as byte absolute $0E23,
   B0EIDL as byte absolute $0E24,
   B0DLC as byte absolute $0E25,
   B0D0 as byte absolute $0E26,
   B0D1 as byte absolute $0E27,
   B0D2 as byte absolute $0E28,
   B0D3 as byte absolute $0E29,
   B0D4 as byte absolute $0E2A,
   B0D5 as byte absolute $0E2B,
   B0D6 as byte absolute $0E2C,
   B0D7 as byte absolute $0E2D,
   CANSTAT_RO9 as byte absolute $0E2E,
   CANCON_RO9 as byte absolute $0E2F,
   B1CON as byte absolute $0E30,
   B1SIDH as byte absolute $0E31,
   B1SIDL as byte absolute $0E32,
   B1EIDH as byte absolute $0E33,
   B1EIDL as byte absolute $0E34,
   B1DLC as byte absolute $0E35,
   B1D0 as byte absolute $0E36,
   B1D1 as byte absolute $0E37,
   B1D2 as byte absolute $0E38,
   B1D3 as byte absolute $0E39,
   B1D4 as byte absolute $0E3A,
   B1D5 as byte absolute $0E3B,
   B1D6 as byte absolute $0E3C,
   B1D7 as byte absolute $0E3D,
   CANSTAT_RO8 as byte absolute $0E3E,
   CANCON_RO8 as byte absolute $0E3F,
   B2CON as byte absolute $0E40,
   B2SIDH as byte absolute $0E41,
   B2SIDL as byte absolute $0E42,
   B2EIDH as byte absolute $0E43,
   B2EIDL as byte absolute $0E44,
   B2DLC as byte absolute $0E45,
   B2D0 as byte absolute $0E46,
   B2D1 as byte absolute $0E47,
   B2D2 as byte absolute $0E48,
   B2D3 as byte absolute $0E49,
   B2D4 as byte absolute $0E4A,
   B2D5 as byte absolute $0E4B,
   B2D6 as byte absolute $0E4C,
   B2D7 as byte absolute $0E4D,
   CANSTAT_RO7 as byte absolute $0E4E,
   CANCON_RO7 as byte absolute $0E4F,
   B3CON as byte absolute $0E50,
   B3SIDH as byte absolute $0E51,
   B3SIDL as byte absolute $0E52,
   B3EIDH as byte absolute $0E53,
   B3EIDL as byte absolute $0E54,
   B3DLC as byte absolute $0E55,
   B3D0 as byte absolute $0E56,
   B3D1 as byte absolute $0E57,
   B3D2 as byte absolute $0E58,
   B3D3 as byte absolute $0E59,
   B3D4 as byte absolute $0E5A,
   B3D5 as byte absolute $0E5B,
   B3D6 as byte absolute $0E5C,
   B3D7 as byte absolute $0E5D,
   CANSTAT_RO6 as byte absolute $0E5E,
   CANCON_RO6 as byte absolute $0E5F,
   B4CON as byte absolute $0E60,
   B4SIDH as byte absolute $0E61,
   B4SIDL as byte absolute $0E62,
   B4EIDH as byte absolute $0E63,
   B4EIDL as byte absolute $0E64,
   B4DLC as byte absolute $0E65,
   B4D0 as byte absolute $0E66,
   B4D1 as byte absolute $0E67,
   B4D2 as byte absolute $0E68,
   B4D3 as byte absolute $0E69,
   B4D4 as byte absolute $0E6A,
   B4D5 as byte absolute $0E6B,
   B4D6 as byte absolute $0E6C,
   B4D7 as byte absolute $0E6D,
   CANSTAT_RO5 as byte absolute $0E6E,
   CANCON_RO5 as byte absolute $0E6F,
   B5CON as byte absolute $0E70,
   B5SIDH as byte absolute $0E71,
   B5SIDL as byte absolute $0E72,
   B5EIDH as byte absolute $0E73,
   B5EIDL as byte absolute $0E74,
   B5DLC as byte absolute $0E75,
   B5D0 as byte absolute $0E76,
   B5D1 as byte absolute $0E77,
   B5D2 as byte absolute $0E78,
   B5D3 as byte absolute $0E79,
   B5D4 as byte absolute $0E7A,
   B5D5 as byte absolute $0E7B,
   B5D6 as byte absolute $0E7C,
   B5D7 as byte absolute $0E7D,
   CANSTAT_RO4 as byte absolute $0E7E,
   CANCON_RO4 as byte absolute $0E7F,
   RXF0SIDH as byte absolute $0F00,
   RXF0SIDL as byte absolute $0F01,
   RXF0EIDH as byte absolute $0F02,
   RXF0EIDL as byte absolute $0F03,
   RXF1SIDH as byte absolute $0F04,
   RXF1SIDL as byte absolute $0F05,
   RXF1EIDH as byte absolute $0F06,
   RXF1EIDL as byte absolute $0F07,
   RXF2SIDH as byte absolute $0F08,
   RXF2SIDL as byte absolute $0F09,
   RXF2EIDH as byte absolute $0F0A,
   RXF2EIDL as byte absolute $0F0B,
   RXF3SIDH as byte absolute $0F0C,
   RXF3SIDL as byte absolute $0F0D,
   RXF3EIDH as byte absolute $0F0E,
   RXF3EIDL as byte absolute $0F0F,
   RXF4SIDH as byte absolute $0F10,
   RXF4SIDL as byte absolute $0F11,
   RXF4EIDH as byte absolute $0F12,
   RXF4EIDL as byte absolute $0F13,
   RXF5SIDH as byte absolute $0F14,
   RXF5SIDL as byte absolute $0F15,
   RXF5EIDH as byte absolute $0F16,
   RXF5EIDL as byte absolute $0F17,
   RXM0SIDH as byte absolute $0F18,
   RXM0SIDL as byte absolute $0F19,
   RXM0EIDH as byte absolute $0F1A,
   RXM0EIDL as byte absolute $0F1B,
   RXM1SIDH as byte absolute $0F1C,
   RXM1SIDL as byte absolute $0F1D,
   RXM1EIDH as byte absolute $0F1E,
   RXM1EIDL as byte absolute $0F1F,
   TXB2CON as byte absolute $0F20,
   TXB2SIDH as byte absolute $0F21,
   TXB2SIDL as byte absolute $0F22,
   TXB2EIDH as byte absolute $0F23,
   TXB2EIDL as byte absolute $0F24,
   TXB2DLC as byte absolute $0F25,
   TXB2D0 as byte absolute $0F26,
   TXB2D1 as byte absolute $0F27,
   TXB2D2 as byte absolute $0F28,
   TXB2D3 as byte absolute $0F29,
   TXB2D4 as byte absolute $0F2A,
   TXB2D5 as byte absolute $0F2B,
   TXB2D6 as byte absolute $0F2C,
   TXB2D7 as byte absolute $0F2D,
   CANSTAT_RO3 as byte absolute $0F2E,
   CANCON_RO3 as byte absolute $0F2F,
   TXB1CON as byte absolute $0F30,
   TXB1SIDH as byte absolute $0F31,
   TXB1SIDL as byte absolute $0F32,
   TXB1EIDH as byte absolute $0F33,
   TXB1EIDL as byte absolute $0F34,
   TXB1DLC as byte absolute $0F35,
   TXB1D0 as byte absolute $0F36,
   TXB1D1 as byte absolute $0F37,
   TXB1D2 as byte absolute $0F38,
   TXB1D3 as byte absolute $0F39,
   TXB1D4 as byte absolute $0F3A,
   TXB1D5 as byte absolute $0F3B,
   TXB1D6 as byte absolute $0F3C,
   TXB1D7 as byte absolute $0F3D,
   CANSTAT_RO2 as byte absolute $0F3E,
   CANCON_RO2 as byte absolute $0F3F,
   TXB0CON as byte absolute $0F40,
   TXB0SIDH as byte absolute $0F41,
   TXB0SIDL as byte absolute $0F42,
   TXB0EIDH as byte absolute $0F43,
   TXB0EIDL as byte absolute $0F44,
   TXB0DLC as byte absolute $0F45,
   TXB0D0 as byte absolute $0F46,
   TXB0D1 as byte absolute $0F47,
   TXB0D2 as byte absolute $0F48,
   TXB0D3 as byte absolute $0F49,
   TXB0D4 as byte absolute $0F4A,
   TXB0D5 as byte absolute $0F4B,
   TXB0D6 as byte absolute $0F4C,
   TXB0D7 as byte absolute $0F4D,
   CANSTAT_RO1 as byte absolute $0F4E,
   CANCON_RO1 as byte absolute $0F4F,
   RXB1CON as byte absolute $0F50,
   RXB1SIDH as byte absolute $0F51,
   RXB1SIDL as byte absolute $0F52,
   RXB1EIDH as byte absolute $0F53,
   RXB1EIDL as byte absolute $0F54,
   RXB1DLC as byte absolute $0F55,
   RXB1D0 as byte absolute $0F56,
   RXB1D1 as byte absolute $0F57,
   RXB1D2 as byte absolute $0F58,
   RXB1D3 as byte absolute $0F59,
   RXB1D4 as byte absolute $0F5A,
   RXB1D5 as byte absolute $0F5B,
   RXB1D6 as byte absolute $0F5C,
   RXB1D7 as byte absolute $0F5D,
   CANSTAT_RO0 as byte absolute $0F5E,
   CANCON_RO0 as byte absolute $0F5F,
   RXB0CON as byte absolute $0F60,
   RXB0SIDH as byte absolute $0F61,
   RXB0SIDL as byte absolute $0F62,
   RXB0EIDH as byte absolute $0F63,
   RXB0EIDL as byte absolute $0F64,
   RXB0DLC as byte absolute $0F65,
   RXB0D0 as byte absolute $0F66,
   RXB0D1 as byte absolute $0F67,
   RXB0D2 as byte absolute $0F68,
   RXB0D3 as byte absolute $0F69,
   RXB0D4 as byte absolute $0F6A,
   RXB0D5 as byte absolute $0F6B,
   RXB0D6 as byte absolute $0F6C,
   RXB0D7 as byte absolute $0F6D,
   CANSTAT as byte absolute $0F6E,
   CANCON as byte absolute $0F6F,
   BRGCON1 as byte absolute $0F70,
   BRGCON2 as byte absolute $0F71,
   BRGCON3 as byte absolute $0F72,
   CIOCON as byte absolute $0F73,
   COMSTAT as byte absolute $0F74,
   RXERRCNT as byte absolute $0F75,
   TXERRCNT as byte absolute $0F76,
   ECANCON as byte absolute $0F77,
   ECCP1DEL as byte absolute $0F79,
   BAUDCON as byte absolute $0F7E,
   SPBRGH as byte absolute $0F7F,
   LATA as byte absolute $0F89,
   LATB as byte absolute $0F8A,
   LATC as byte absolute $0F8B,
   LATD as byte absolute $0F8C,
   LATE as byte absolute $0F8D,
   LATF as byte absolute $0F8E,
   LATG as byte absolute $0F8F,
   DDRA as byte absolute $0F92,
   TRISA as byte absolute $0F92,
   DDRB as byte absolute $0F93,
   TRISB as byte absolute $0F93,
   DDRC as byte absolute $0F94,
   TRISC as byte absolute $0F94,
   DDRD as byte absolute $0F95,
   TRISD as byte absolute $0F95,
   DDRE as byte absolute $0F96,
   TRISE as byte absolute $0F96,
   DDRF as byte absolute $0F97,
   TRISF as byte absolute $0F97,
   DDRG as byte absolute $0F98,
   TRISG as byte absolute $0F98,
   PIE1 as byte absolute $0F9D,
   PIR1 as byte absolute $0F9E,
   IPR1 as byte absolute $0F9F,
   PIE2 as byte absolute $0FA0,
   PIR2 as byte absolute $0FA1,
   IPR2 as byte absolute $0FA2,
   PIE3 as byte absolute $0FA3,
   PIR3 as byte absolute $0FA4,
   IPR3 as byte absolute $0FA5,
   EECON1 as byte absolute $0FA6,
   EECON2 as byte absolute $0FA7,
   EEDATA as byte absolute $0FA8,
   EEADR as byte absolute $0FA9,
   EEADRH as byte absolute $0FAA,
   RCSTA as byte absolute $0FAB,
   RCSTA1 as byte absolute $0FAB,
   TXSTA as byte absolute $0FAC,
   TXSTA1 as byte absolute $0FAC,
   TXREG as byte absolute $0FAD,
   TXREG1 as byte absolute $0FAD,
   RCREG as byte absolute $0FAE,
   RCREG1 as byte absolute $0FAE,
   SPBRG as byte absolute $0FAF,
   SPBRG1 as byte absolute $0FAF,
   PSPCON as byte absolute $0FB0,
   T3CON as byte absolute $0FB1,
   TMR3 as byte absolute $0FB2,
   TMR3L as byte absolute $0FB2,
   TMR3H as byte absolute $0FB3,
   CMCON as byte absolute $0FB4,
   CVRCON as byte absolute $0FB5,
   ECCP1AS as byte absolute $0FB6,
   CCP2CON as byte absolute $0FBA,
   CCPR2 as byte absolute $0FBB,
   CCPR2L as byte absolute $0FBB,
   CCPR2H as byte absolute $0FBC,
   CCP1CON as byte absolute $0FBD,
   CCPR1 as byte absolute $0FBE,
   CCPR1L as byte absolute $0FBE,
   CCPR1H as byte absolute $0FBF,
   ADCON2 as byte absolute $0FC0,
   ADCON1 as byte absolute $0FC1,
   ADCON0 as byte absolute $0FC2,
   ADRES as byte absolute $0FC3,
   ADRESL as byte absolute $0FC3,
   ADRESH as byte absolute $0FC4,
   SSPCON2 as byte absolute $0FC5,
   SSPCON1 as byte absolute $0FC6,
   SSPSTAT as byte absolute $0FC7,
   SSPADD as byte absolute $0FC8,
   SSPBUF as byte absolute $0FC9,
   T2CON as byte absolute $0FCA,
   PR2 as byte absolute $0FCB,
   TMR2 as byte absolute $0FCC,
   T1CON as byte absolute $0FCD,
   TMR1 as byte absolute $0FCE,
   TMR1L as byte absolute $0FCE,
   TMR1H as byte absolute $0FCF,
   RCON as byte absolute $0FD0,
   WDTCON as byte absolute $0FD1,
   LVDCON as byte absolute $0FD2,
   OSCCON as byte absolute $0FD3,
   T0CON as byte absolute $0FD5,
   TMR0 as byte absolute $0FD6,
   TMR0L as byte absolute $0FD6,
   TMR0H as byte absolute $0FD7,
   STATUS as byte absolute $0FD8,
   FSR2L as byte absolute $0FD9,
   FSR2H as byte absolute $0FDA,
   PLUSW2 as byte absolute $0FDB,
   PREINC2 as byte absolute $0FDC,
   POSTDEC2 as byte absolute $0FDD,
   POSTINC2 as byte absolute $0FDE,
   INDF2 as byte absolute $0FDF,
   BSR as byte absolute $0FE0,
   FSR1L as byte absolute $0FE1,
   FSR1H as byte absolute $0FE2,
   PLUSW1 as byte absolute $0FE3,
   PREINC1 as byte absolute $0FE4,
   POSTDEC1 as byte absolute $0FE5,
   POSTINC1 as byte absolute $0FE6,
   INDF1 as byte absolute $0FE7,
   WREG as byte absolute $0FE8,
   FSR0L as byte absolute $0FE9,
   FSR0H as byte absolute $0FEA,
   PLUSW0 as byte absolute $0FEB,
   PREINC0 as byte absolute $0FEC,
   POSTDEC0 as byte absolute $0FED,
   POSTINC0 as byte absolute $0FEE,
   INDF0 as byte absolute $0FEF,
   INTCON3 as byte absolute $0FF0,
   INTCON2 as byte absolute $0FF1,
   INTCON as byte absolute $0FF2,
   PRODL as byte absolute $0FF3,
   PRODH as byte absolute $0FF4,
   TABLAT as byte absolute $0FF5,
   TBLPTR as byte absolute $0FF6,
   TBLPTRL as byte absolute $0FF6,
   TBLPTRH as byte absolute $0FF7,
   TBLPTRU as byte absolute $0FF8,
   PC as byte absolute $0FF9,
   PCL as byte absolute $0FF9,
   PCLATH as byte absolute $0FFA,
   PCLATU as byte absolute $0FFB,
   STKPTR as byte absolute $0FFC,
   TOS as byte absolute $0FFD,
   TOSL as byte absolute $0FFD,
   TOSH as byte absolute $0FFE,
   TOSU as byte absolute $0FFF

// system ports...
public system port
   PORTA as byte absolute $0F80,
   PORTB as byte absolute $0F81,
   PORTC as byte absolute $0F82,
   PORTD as byte absolute $0F83,
   PORTE as byte absolute $0F84,
   PORTF as byte absolute $0F85,
   PORTG as byte absolute $0F86

// alias...
public dim
   PROD as PRODL.AsWord,
   FSR0 as FSR0L.AsWord,
   FSR1 as FSR1L.AsWord,
   FSR2 as FSR2L.AsWord,
   TABLEPTR as TBLPTRL.AsWord

// configuration fuses...
public config
   OSC(OSC) = [LP, XT, HS, RC, EC, ECIO, HSPLL, RCIO, ECIOPLL, ECIOSWPLL, HSSWPLL],
   OSCS(OSCS) = [ON, OFF],
   PWRT(PWRT) = [ON, OFF],
   BOR(BOR) = [OFF, ON],
   BORV(BORV) = [45, 42, 27, 20],
   WDT(WDT) = [OFF, ON],
   WDTPS(WDTPS) = [1, 2, 4, 8, 16, 32, 64, 128, 256, 512, 1024, 2048, 4096, 8192, 16384, 32768],
   CCP2MX(CCP2MX) = [OFF, ON],
   MCLRE(MCLRE) = [OFF, ON],
   STVR(STVR) = [OFF, ON],
   LVP(LVP) = [OFF, ON],
   DEBUG(DEBUG) = [ON, OFF],
   CP0(CP0) = [ON, OFF],
   CP1(CP1) = [ON, OFF],
   CP2(CP2) = [ON, OFF],
   CP3(CP3) = [ON, OFF],
   CPB(CPB) = [ON, OFF],
   CPD(CPD) = [ON, OFF],
   WRT0(WRT0) = [ON, OFF],
   WRT1(WRT1) = [ON, OFF],
   WRT2(WRT2) = [ON, OFF],
   WRT3(WRT3) = [ON, OFF],
   WRTC(WRTC) = [ON, OFF],
   WRTB(WRTB) = [ON, OFF],
   WRTD(WRTD) = [ON, OFF],
   EBTR0(EBTR0) = [ON, OFF],
   EBTR1(EBTR1) = [ON, OFF],
   EBTR2(EBTR2) = [ON, OFF],
   EBTR3(EBTR3) = [ON, OFF],
   EBTRB(EBTRB) = [ON, OFF]

// default fuses...
config
   OSC = HS,
   OSCS = OFF,
   PWRT = ON,
   BOR = ON,
   BORV = 20,
   WDT = OFF,
   WDTPS = 128,
   STVR = ON,
   LVP = OFF,
   DEBUG = OFF
