{
****************************************************************
*  Name    : 18F66J94                                          *
*  Author  : David John Barker                                 *
*  Notice  : Copyright (c) 2015 Mecanique                      *
*          : All Rights Reserved                               *
*  Date    : 7/3/2015                                          *
****************************************************************
}

module SystemTypes

// system header...
#const _core = $0012                   // processor core
#const _ram_banks = $0E                // 14 RAM bank(s) used
#variable _maxaccess = $60             // access ram is 96 bytes
#variable _maxram = $0DFA              // 3578 bytes of user RAM
#variable _maxrom = $00FFF0            // 63 KB of program ROM
#const _eeprom = $0000                 // 0 bytes of EEPROM
#const _eeprom_start = $F00000         // EEPROM start address
#const _ports = $07                    // 7 available ports
#const _ccp = $06                      // 6 CCP module(s) available
#const _eccp = $03                     // 3 ECCP module(s) available
#const _mssp = $02                     // 2 MSSP module(s) available
#const _usart = $02                    // 2 USART(s) available
#const _adc = $00                      // 0 ADC channels available
#const _comparator = $03               // 3 comparator(s) available
#const _psp = $01                      // onboard Parallel Slave Port (PSP) available
#const _can = $00                      // onboard CAN is NOT supported
#const _usb = $01                      // onboard USB available
#const _ethernet = $00                 // onboard Ethernet is NOT supported
#const _flash_write = $01              // FLASH has write capability
#const _wdt_type = $03                 // WDTEN watchdog (w/SWDTDIS)

// special function registers...
public system
   UEP0 as byte absolute $0DFF,
   UEP1 as byte absolute $0E00,
   UEP2 as byte absolute $0E01,
   UEP3 as byte absolute $0E02,
   UEP4 as byte absolute $0E03,
   UEP5 as byte absolute $0E04,
   UEP6 as byte absolute $0E05,
   UEP7 as byte absolute $0E06,
   UEP8 as byte absolute $0E07,
   UEP9 as byte absolute $0E08,
   UEP10 as byte absolute $0E09,
   UEP11 as byte absolute $0E0A,
   UEP12 as byte absolute $0E0B,
   UEP13 as byte absolute $0E0C,
   UEP14 as byte absolute $0E0D,
   UEP15 as byte absolute $0E0E,
   UEIE as byte absolute $0E0F,
   UIE as byte absolute $0E10,
   UCFG as byte absolute $0E11,
   RPOR0_1 as byte absolute $0E12,
   RPOR2_3 as byte absolute $0E13,
   RPOR4_5 as byte absolute $0E14,
   RPOR6_7 as byte absolute $0E15,
   RPOR8_9 as byte absolute $0E16,
   RPOR10_11 as byte absolute $0E17,
   RPOR12_13 as byte absolute $0E18,
   RPOR14_15 as byte absolute $0E19,
   RPOR16_17 as byte absolute $0E1A,
   RPOR18_19 as byte absolute $0E1B,
   RPOR20_21 as byte absolute $0E1C,
   RPOR22_23 as byte absolute $0E1D,
   RPOR24_25 as byte absolute $0E1E,
   RPOR26_27 as byte absolute $0E1F,
   RPOR28_29 as byte absolute $0E20,
   RPOR30_31 as byte absolute $0E21,
   RPOR32_33 as byte absolute $0E22,
   RPOR34_35 as byte absolute $0E23,
   RPOR36_37 as byte absolute $0E24,
   RPOR38_39 as byte absolute $0E25,
   RPOR40_41 as byte absolute $0E26,
   RPOR42_43 as byte absolute $0E27,
   RPOR44_45 as byte absolute $0E28,
   RPOR46 as byte absolute $0E29,
   RPINR0_1 as byte absolute $0E2A,
   RPINR2_3 as byte absolute $0E2B,
   RPINR4_5 as byte absolute $0E2C,
   RPINR6_7 as byte absolute $0E2D,
   RPINR8_9 as byte absolute $0E2E,
   RPINR10_11 as byte absolute $0E2F,
   RPINR12_13 as byte absolute $0E30,
   RPINR14_15 as byte absolute $0E31,
   RPINR16_17 as byte absolute $0E32,
   RPINR18_19 as byte absolute $0E33,
   RPINR20_21 as byte absolute $0E34,
   RPINR22_23 as byte absolute $0E35,
   RPINR24_25 as byte absolute $0E36,
   RPINR26_27 as byte absolute $0E37,
   RPINR28_29 as byte absolute $0E38,
   RPINR30_31 as byte absolute $0E39,
   RPINR32_33 as byte absolute $0E3A,
   RPINR34_35 as byte absolute $0E3B,
   RPINR36_37 as byte absolute $0E3C,
   RPINR38_39 as byte absolute $0E3D,
   RPINR40_41 as byte absolute $0E3E,
   RPINR42_43 as byte absolute $0E3F,
   RPINR44_45 as byte absolute $0E40,
   RPINR46_47 as byte absolute $0E41,
   RPINR48_49 as byte absolute $0E42,
   RPINR50_51 as byte absolute $0E43,
   RPINR52_53 as byte absolute $0E44,
   ANCON3 as byte absolute $0E45,
   ANCON2 as byte absolute $0E46,
   ANCON1 as byte absolute $0E47,
   ADCBUF1 as byte absolute $0E48,
   ADCBUF1L as byte absolute $0E48,
   ADCBUF1H as byte absolute $0E49,
   ADCBUF2 as byte absolute $0E4A,
   ADCBUF2L as byte absolute $0E4A,
   ADCBUF2H as byte absolute $0E4B,
   ADCBUF3 as byte absolute $0E4C,
   ADCBUF3L as byte absolute $0E4C,
   ADCBUF3H as byte absolute $0E4D,
   ADCBUF4 as byte absolute $0E4E,
   ADCBUF4L as byte absolute $0E4E,
   ADCBUF4H as byte absolute $0E4F,
   ADCBUF5 as byte absolute $0E50,
   ADCBUF5L as byte absolute $0E50,
   ADCBUF5H as byte absolute $0E51,
   ADCBUF6 as byte absolute $0E52,
   ADCBUF6L as byte absolute $0E52,
   ADCBUF6H as byte absolute $0E53,
   ADCBUF7 as byte absolute $0E54,
   ADCBUF7L as byte absolute $0E54,
   ADCBUF7H as byte absolute $0E55,
   ADCBUF8 as byte absolute $0E56,
   ADCBUF8L as byte absolute $0E56,
   ADCBUF8H as byte absolute $0E57,
   ADCBUF9 as byte absolute $0E58,
   ADCBUF9L as byte absolute $0E58,
   ADCBUF9H as byte absolute $0E59,
   ADCBUF10 as byte absolute $0E5A,
   ADCBUF10L as byte absolute $0E5A,
   ADCBUF10H as byte absolute $0E5B,
   ADCBUF11 as byte absolute $0E5C,
   ADCBUF11L as byte absolute $0E5C,
   ADCBUF11H as byte absolute $0E5D,
   ADCBUF12 as byte absolute $0E5E,
   ADCBUF12L as byte absolute $0E5E,
   ADCBUF12H as byte absolute $0E5F,
   ADCBUF13 as byte absolute $0E60,
   ADCBUF13L as byte absolute $0E60,
   ADCBUF13H as byte absolute $0E61,
   ADCBUF14 as byte absolute $0E62,
   ADCBUF14L as byte absolute $0E62,
   ADCBUF14H as byte absolute $0E63,
   ADCBUF15 as byte absolute $0E64,
   ADCBUF15L as byte absolute $0E64,
   ADCBUF15H as byte absolute $0E65,
   ADCBUF16 as byte absolute $0E66,
   ADCBUF16L as byte absolute $0E66,
   ADCBUF16H as byte absolute $0E67,
   ADCBUF17 as byte absolute $0E68,
   ADCBUF17L as byte absolute $0E68,
   ADCBUF17H as byte absolute $0E69,
   ADCBUF18 as byte absolute $0E6A,
   ADCBUF18L as byte absolute $0E6A,
   ADCBUF18H as byte absolute $0E6B,
   ADCBUF19 as byte absolute $0E6C,
   ADCBUF19L as byte absolute $0E6C,
   ADCBUF19H as byte absolute $0E6D,
   ADCBUF20 as byte absolute $0E6E,
   ADCBUF20L as byte absolute $0E6E,
   ADCBUF20H as byte absolute $0E6F,
   ADCBUF21 as byte absolute $0E70,
   ADCBUF21L as byte absolute $0E70,
   ADCBUF21H as byte absolute $0E71,
   ADCBUF22 as byte absolute $0E72,
   ADCBUF22L as byte absolute $0E72,
   ADCBUF22H as byte absolute $0E73,
   ADCBUF23 as byte absolute $0E74,
   ADCBUF23L as byte absolute $0E74,
   ADCBUF23H as byte absolute $0E75,
   ADCBUF24 as byte absolute $0E76,
   ADCBUF24L as byte absolute $0E76,
   ADCBUF24H as byte absolute $0E77,
   ADCBUF25 as byte absolute $0E78,
   ADCBUF25L as byte absolute $0E78,
   ADCBUF25H as byte absolute $0E79,
   ADCTMUEN0L as byte absolute $0E7A,
   ADCTMUEN0H as byte absolute $0E7B,
   ADCTMUEN1L as byte absolute $0E7C,
   ADCTMUEN1H as byte absolute $0E7D,
   ADCHIT0L as byte absolute $0E7E,
   ADCHIT0H as byte absolute $0E7F,
   ADCHIT1L as byte absolute $0E80,
   ADCHIT1H as byte absolute $0E81,
   ADCSS0L as byte absolute $0E82,
   ADCSS0H as byte absolute $0E83,
   ADCSS1L as byte absolute $0E84,
   ADCSS1H as byte absolute $0E85,
   ADCHS0L as byte absolute $0E86,
   ADCHS0H as byte absolute $0E87,
   ADCON5L as byte absolute $0E88,
   ADCON5H as byte absolute $0E89,
   ADCON3L as byte absolute $0E8A,
   ADCON3H as byte absolute $0E8B,
   ADCON2L as byte absolute $0E8C,
   ADCON2H as byte absolute $0E8D,
   LCDDATA0 as byte absolute $0E8E,
   LCDDATA1 as byte absolute $0E8F,
   LCDDATA2 as byte absolute $0E90,
   LCDDATA3 as byte absolute $0E91,
   LCDDATA4 as byte absolute $0E92,
   LCDDATA5 as byte absolute $0E93,
   LCDDATA6 as byte absolute $0E94,
   LCDDATA7 as byte absolute $0E95,
   LCDDATA8 as byte absolute $0E96,
   LCDDATA9 as byte absolute $0E97,
   LCDDATA10 as byte absolute $0E98,
   LCDDATA11 as byte absolute $0E99,
   LCDDATA12 as byte absolute $0E9A,
   LCDDATA13 as byte absolute $0E9B,
   LCDDATA14 as byte absolute $0E9C,
   LCDDATA15 as byte absolute $0E9D,
   LCDDATA16 as byte absolute $0E9E,
   LCDDATA17 as byte absolute $0E9F,
   LCDDATA18 as byte absolute $0EA0,
   LCDDATA19 as byte absolute $0EA1,
   LCDDATA20 as byte absolute $0EA2,
   LCDDATA21 as byte absolute $0EA3,
   LCDDATA22 as byte absolute $0EA4,
   LCDDATA23 as byte absolute $0EA5,
   LCDDATA24 as byte absolute $0EA6,
   LCDDATA25 as byte absolute $0EA7,
   LCDDATA26 as byte absolute $0EA8,
   LCDDATA27 as byte absolute $0EA9,
   LCDDATA28 as byte absolute $0EAA,
   LCDDATA29 as byte absolute $0EAB,
   LCDDATA30 as byte absolute $0EAC,
   LCDDATA31 as byte absolute $0EAD,
   LCDDATA32 as byte absolute $0EAE,
   LCDDATA33 as byte absolute $0EAF,
   LCDDATA34 as byte absolute $0EB0,
   LCDDATA35 as byte absolute $0EB1,
   LCDDATA36 as byte absolute $0EB2,
   LCDDATA37 as byte absolute $0EB3,
   LCDDATA38 as byte absolute $0EB4,
   LCDDATA39 as byte absolute $0EB5,
   LCDDATA40 as byte absolute $0EB6,
   LCDDATA41 as byte absolute $0EB7,
   LCDDATA42 as byte absolute $0EB8,
   LCDDATA43 as byte absolute $0EB9,
   LCDDATA44 as byte absolute $0EBA,
   LCDDATA45 as byte absolute $0EBB,
   LCDDATA46 as byte absolute $0EBC,
   LCDDATA47 as byte absolute $0EBD,
   LCDDATA48 as byte absolute $0EBE,
   LCDDATA49 as byte absolute $0EBF,
   LCDDATA50 as byte absolute $0EC0,
   LCDDATA51 as byte absolute $0EC1,
   LCDDATA52 as byte absolute $0EC2,
   LCDDATA53 as byte absolute $0EC3,
   LCDDATA54 as byte absolute $0EC4,
   LCDDATA55 as byte absolute $0EC5,
   LCDDATA56 as byte absolute $0EC6,
   LCDDATA57 as byte absolute $0EC7,
   LCDDATA58 as byte absolute $0EC8,
   LCDDATA59 as byte absolute $0EC9,
   LCDDATA60 as byte absolute $0ECA,
   LCDDATA61 as byte absolute $0ECB,
   LCDDATA62 as byte absolute $0ECC,
   LCDDATA63 as byte absolute $0ECD,
   LCDSE0 as byte absolute $0ECE,
   LCDSE1 as byte absolute $0ECF,
   LCDSE2 as byte absolute $0ED0,
   LCDSE3 as byte absolute $0ED1,
   LCDSE4 as byte absolute $0ED2,
   LCDSE5 as byte absolute $0ED3,
   LCDSE6 as byte absolute $0ED4,
   LCDSE7 as byte absolute $0ED5,
   LCDRL as byte absolute $0ED6,
   LCDREF as byte absolute $0ED7,
   LCDREG as byte absolute $0ED8,
   LCDCON as byte absolute $0ED9,
   LCDPS as byte absolute $0EDA,
   REFO2CON3 as byte absolute $0EDB,
   REFO2CON2 as byte absolute $0EDC,
   REFO2CON1 as byte absolute $0EDD,
   REFO2CON as byte absolute $0EDE,
   REFO1CON3 as byte absolute $0EDF,
   REFO1CON2 as byte absolute $0EE0,
   REFO1CON1 as byte absolute $0EE1,
   REFO1CON as byte absolute $0EE2,
   ODCON2 as byte absolute $0EEA,
   ODCON1 as byte absolute $0EEB,
   MDCARL as byte absolute $0EEC,
   MDCARH as byte absolute $0EED,
   MDSRC as byte absolute $0EEE,
   MDCON as byte absolute $0EEF,
   PMD4 as byte absolute $0EF0,
   PMD3 as byte absolute $0EF1,
   PMD2 as byte absolute $0EF2,
   PMD1 as byte absolute $0EF3,
   PMD0 as byte absolute $0EF4,
   CTMUCON4 as byte absolute $0EF5,
   CTMUCON3 as byte absolute $0EF6,
   CTMUCON2 as byte absolute $0EF7,
   CTMUCON1 as byte absolute $0EF8,
   TXREG4 as byte absolute $0EF9,
   RCREG4 as byte absolute $0EFA,
   SPBRG4 as byte absolute $0EFB,
   SPBRGH4 as byte absolute $0EFC,
   BAUDCON4 as byte absolute $0EFD,
   TXSTA4 as byte absolute $0EFE,
   RCSTA4 as byte absolute $0EFF,
   DMACON2 as byte absolute $0F00,
   ANCFG as byte absolute $0F01,
   SSP2ADD as byte absolute $0F02,
   SSP2BUF as byte absolute $0F03,
   T4CON as byte absolute $0F04,
   PR4 as byte absolute $0F05,
   TMR4 as byte absolute $0F06,
   CCP7CON as byte absolute $0F07,
   CCPR7 as byte absolute $0F08,
   CCPR7L as byte absolute $0F08,
   CCPR7H as byte absolute $0F09,
   CCP6CON as byte absolute $0F0A,
   CCPR6 as byte absolute $0F0B,
   CCPR6L as byte absolute $0F0B,
   CCPR6H as byte absolute $0F0C,
   CCP5CON as byte absolute $0F0D,
   CCPR5 as byte absolute $0F0E,
   CCPR5L as byte absolute $0F0E,
   CCPR5H as byte absolute $0F0F,
   CCP4CON as byte absolute $0F10,
   CCPR4 as byte absolute $0F11,
   CCPR4L as byte absolute $0F11,
   CCPR4H as byte absolute $0F12,
   T5GCON as byte absolute $0F13,
   T5CON as byte absolute $0F14,
   TMR5 as byte absolute $0F15,
   TMR5L as byte absolute $0F15,
   TMR5H as byte absolute $0F16,
   SSP2MSK as byte absolute $0F17,
   SSP2CON2 as byte absolute $0F18,
   SSP2CON1 as byte absolute $0F19,
   SSP2STAT as byte absolute $0F1A,
   PSTR3CON as byte absolute $0F1B,
   PSTR2CON as byte absolute $0F1C,
   TXREG2 as byte absolute $0F1D,
   RCREG2 as byte absolute $0F1E,
   SPBRG2 as byte absolute $0F1F,
   SPBRGH2 as byte absolute $0F20,
   DSGPR3 as byte absolute $0F21,
   DSGPR2 as byte absolute $0F22,
   DSGPR1 as byte absolute $0F23,
   DSGPR0 as byte absolute $0F24,
   DSWAKEH as byte absolute $0F25,
   DSWAKEL as byte absolute $0F26,
   DSCONH as byte absolute $0F27,
   DSCONL as byte absolute $0F28,
   TXREG3 as byte absolute $0F29,
   RCREG3 as byte absolute $0F2A,
   SPBRG3 as byte absolute $0F2B,
   SPBRGH3 as byte absolute $0F2C,
   BAUDCON3 as byte absolute $0F2D,
   TXSTA3 as byte absolute $0F2E,
   RCSTA3 as byte absolute $0F2F,
   SPBRGH as byte absolute $0F30,
   SPBRGH1 as byte absolute $0F30,
   BAUDCON2 as byte absolute $0F31,
   TXSTA2 as byte absolute $0F32,
   RCSTA2 as byte absolute $0F33,
   CCPTMRS2 as byte absolute $0F34,
   CCPTMRS1 as byte absolute $0F35,
   CCPTMRS0 as byte absolute $0F36,
   CM3CON as byte absolute $0F37,
   CM2CON as byte absolute $0F38,
   SSP2CON3 as byte absolute $0F39,
   T8CON as byte absolute $0F3A,
   PR8 as byte absolute $0F3B,
   TMR8 as byte absolute $0F3C,
   T6CON as byte absolute $0F3D,
   PR6 as byte absolute $0F3E,
   TMR6 as byte absolute $0F3F,
   CCP10CON as byte absolute $0F40,
   CCPR10 as byte absolute $0F41,
   CCPR10L as byte absolute $0F41,
   CCPR10H as byte absolute $0F42,
   CCP9CON as byte absolute $0F43,
   CCPR9 as byte absolute $0F44,
   CCPR9L as byte absolute $0F44,
   CCPR9H as byte absolute $0F45,
   CCP8CON as byte absolute $0F46,
   CCPR8 as byte absolute $0F47,
   CCPR8L as byte absolute $0F47,
   CCPR8H as byte absolute $0F48,
   CCP3CON as byte absolute $0F49,
   CCPR3 as byte absolute $0F4A,
   CCPR3L as byte absolute $0F4A,
   CCPR3H as byte absolute $0F4B,
   ECCP3DEL as byte absolute $0F4C,
   ECCP3AS as byte absolute $0F4D,
   CCP2CON as byte absolute $0F4E,
   CCPR2 as byte absolute $0F4F,
   CCPR2L as byte absolute $0F4F,
   CCPR2H as byte absolute $0F50,
   ECCP2DEL as byte absolute $0F51,
   ECCP2AS as byte absolute $0F52,
   CM1CON as byte absolute $0F53,
   PADCFG1 as byte absolute $0F54,
   IOCN as byte absolute $0F55,
   IOCP as byte absolute $0F56,
   RTCCON2 as byte absolute $0F57,
   ALRMVALL as byte absolute $0F58,
   ALRMVALH as byte absolute $0F59,
   ALRMRPT as byte absolute $0F5A,
   ALRMCFG as byte absolute $0F5B,
   RTCVALL as byte absolute $0F5C,
   RTCVALH as byte absolute $0F5D,
   RTCCAL as byte absolute $0F5E,
   RTCCON1 as byte absolute $0F5F,
   DMACON1 as byte absolute $0F60,
   PIE6 as byte absolute $0F61,
   WPUB as byte absolute $0F62,
   ACTCON as byte absolute $0F63,
   OSCCON4 as byte absolute $0F64,
   OSCCON3 as byte absolute $0F65,
   OSCCON2 as byte absolute $0F66,
   BAUDCON as byte absolute $0F67,
   BAUDCON1 as byte absolute $0F67,
   SSP1MSK as byte absolute $0F68,
   SSP1CON3 as byte absolute $0F69,
   TXBUF as byte absolute $0F6A,
   DMABCH as byte absolute $0F6B,
   DMABCL as byte absolute $0F6C,
   RXADDRH as byte absolute $0F6D,
   RXADDRL as byte absolute $0F6E,
   TXADDRH as byte absolute $0F6F,
   TXADDRL as byte absolute $0F70,
   PORTVP as byte absolute $0F71,
   LATVP as byte absolute $0F72,
   TRISVP as byte absolute $0F73,
   UADDR as byte absolute $0F74,
   UCON as byte absolute $0F75,
   USTAT as byte absolute $0F76,
   UEIR as byte absolute $0F77,
   UIR as byte absolute $0F78,
   UFRM as byte absolute $0F79,
   UFRMH as byte absolute $0F79,
   UFRML as byte absolute $0F7A,
   RCON4 as byte absolute $0F7B,
   RCON3 as byte absolute $0F7C,
   RCON2 as byte absolute $0F7D,
   EECON2 as byte absolute $0F7E,
   EECON1 as byte absolute $0F7F,
   LATA as byte absolute $0F89,
   LATB as byte absolute $0F8A,
   LATC as byte absolute $0F8B,
   LATD as byte absolute $0F8C,
   LATE as byte absolute $0F8D,
   LATF as byte absolute $0F8E,
   LATG as byte absolute $0F8F,
   TRISA as byte absolute $0F92,
   TRISB as byte absolute $0F93,
   TRISC as byte absolute $0F94,
   TRISD as byte absolute $0F95,
   TRISE as byte absolute $0F96,
   TRISF as byte absolute $0F97,
   TRISG as byte absolute $0F98,
   OSCTUNE as byte absolute $0F9B,
   PSTR1CON as byte absolute $0F9C,
   PIE1 as byte absolute $0F9D,
   PIR1 as byte absolute $0F9E,
   IPR1 as byte absolute $0F9F,
   PIE2 as byte absolute $0FA0,
   PIR2 as byte absolute $0FA1,
   IPR2 as byte absolute $0FA2,
   PIE3 as byte absolute $0FA3,
   PIR3 as byte absolute $0FA4,
   IPR3 as byte absolute $0FA5,
   PIR6 as byte absolute $0FA6,
   PSPCON as byte absolute $0FA7,
   HLVDCON as byte absolute $0FA8,
   IPR6 as byte absolute $0FA9,
   T1GCON as byte absolute $0FAA,
   RCSTA as byte absolute $0FAB,
   RCSTA1 as byte absolute $0FAB,
   TXSTA as byte absolute $0FAC,
   TXSTA1 as byte absolute $0FAC,
   TXREG as byte absolute $0FAD,
   TXREG1 as byte absolute $0FAD,
   RCREG as byte absolute $0FAE,
   RCREG1 as byte absolute $0FAE,
   SPBRG as byte absolute $0FAF,
   SPBRG1 as byte absolute $0FAF,
   T3GCON as byte absolute $0FB0,
   T3CON as byte absolute $0FB1,
   TMR3 as byte absolute $0FB2,
   TMR3L as byte absolute $0FB2,
   TMR3H as byte absolute $0FB3,
   PIE4 as byte absolute $0FB4,
   PIR4 as byte absolute $0FB5,
   IPR4 as byte absolute $0FB6,
   PIE5 as byte absolute $0FB7,
   PIR5 as byte absolute $0FB8,
   CCP1CON as byte absolute $0FB9,
   CCPR1 as byte absolute $0FBA,
   CCPR1L as byte absolute $0FBA,
   CCPR1H as byte absolute $0FBB,
   ECCP1DEL as byte absolute $0FBC,
   ECCP1AS as byte absolute $0FBD,
   CVRCONL as byte absolute $0FBE,
   CVRCONH as byte absolute $0FBF,
   ADCON1L as byte absolute $0FC0,
   ADCON1H as byte absolute $0FC1,
   ADCBUF0 as byte absolute $0FC2,
   ADCBUF0L as byte absolute $0FC2,
   ADCBUF0H as byte absolute $0FC3,
   CMSTAT as byte absolute $0FC4,
   SSP1CON2 as byte absolute $0FC5,
   SSP1CON1 as byte absolute $0FC6,
   SSP1STAT as byte absolute $0FC7,
   SSP1ADD as byte absolute $0FC8,
   SSP1BUF as byte absolute $0FC9,
   T2CON as byte absolute $0FCA,
   PR2 as byte absolute $0FCB,
   TMR2 as byte absolute $0FCC,
   T1CON as byte absolute $0FCD,
   TMR1 as byte absolute $0FCE,
   TMR1L as byte absolute $0FCE,
   TMR1H as byte absolute $0FCF,
   RCON as byte absolute $0FD0,
   IOCF as byte absolute $0FD1,
   IPR5 as byte absolute $0FD2,
   OSCCON as byte absolute $0FD3,
   T0CON as byte absolute $0FD5,
   TMR0 as byte absolute $0FD6,
   TMR0L as byte absolute $0FD6,
   TMR0H as byte absolute $0FD7,
   STATUS as byte absolute $0FD8,
   FSR2L as byte absolute $0FD9,
   FSR2H as byte absolute $0FDA,
   PLUSW2 as byte absolute $0FDB,
   PREINC2 as byte absolute $0FDC,
   POSTDEC2 as byte absolute $0FDD,
   POSTINC2 as byte absolute $0FDE,
   INDF2 as byte absolute $0FDF,
   BSR as byte absolute $0FE0,
   FSR1L as byte absolute $0FE1,
   FSR1H as byte absolute $0FE2,
   PLUSW1 as byte absolute $0FE3,
   PREINC1 as byte absolute $0FE4,
   POSTDEC1 as byte absolute $0FE5,
   POSTINC1 as byte absolute $0FE6,
   INDF1 as byte absolute $0FE7,
   WREG as byte absolute $0FE8,
   FSR0L as byte absolute $0FE9,
   FSR0H as byte absolute $0FEA,
   PLUSW0 as byte absolute $0FEB,
   PREINC0 as byte absolute $0FEC,
   POSTDEC0 as byte absolute $0FED,
   POSTINC0 as byte absolute $0FEE,
   INDF0 as byte absolute $0FEF,
   INTCON3 as byte absolute $0FF0,
   INTCON2 as byte absolute $0FF1,
   INTCON as byte absolute $0FF2,
   PRODL as byte absolute $0FF3,
   PRODH as byte absolute $0FF4,
   TABLAT as byte absolute $0FF5,
   TBLPTR as byte absolute $0FF6,
   TBLPTRL as byte absolute $0FF6,
   TBLPTRH as byte absolute $0FF7,
   TBLPTRU as byte absolute $0FF8,
   PC as byte absolute $0FF9,
   PCL as byte absolute $0FF9,
   PCLATH as byte absolute $0FFA,
   PCLATU as byte absolute $0FFB,
   STKPTR as byte absolute $0FFC,
   TOS as byte absolute $0FFD,
   TOSL as byte absolute $0FFD,
   TOSH as byte absolute $0FFE,
   TOSU as byte absolute $0FFF

// system ports...
public system port
   PORTA as byte absolute $0F80,
   PORTB as byte absolute $0F81,
   PORTC as byte absolute $0F82,
   PORTD as byte absolute $0F83,
   PORTE as byte absolute $0F84,
   PORTF as byte absolute $0F85,
   PORTG as byte absolute $0F86

// alias...
public dim
   PROD as PRODL.AsWord,
   FSR0 as FSR0L.AsWord,
   FSR1 as FSR1L.AsWord,
   FSR2 as FSR2L.AsWord,
   TABLEPTR as TBLPTRL.AsWord

// configuration fuses...
public config
   STVREN(STVREN) = [OFF, ON],
   XINST(XINST) = [OFF, ON],
   BOREN(BOREN) = [OFF, ON],
   BORV(BORV) = [0, 1],
   CP0(CP0) = [ON, OFF],
   FOSC(FOSC) = [FRC, FRCPLL, PRI, PRIPLL, SOSC, LPRC, FRC500KHZ, FRCDIV],
   SOSCSEL(SOSCSEL) = [DIG, LOW],
   CLKOEN(CLKOEN) = [OFF, ON],
   IESO(IESO) = [OFF, ON],
   PLLDIV(PLLDIV) = [NODIV, DIV2, DIV3, DIV4, DIV5, DIV6, DIV10, DIV12, PLL4X, PLL6X, PLL8X, NOPLL],
   POSCMD(POSCMD) = [EC, MS, HS, NONE],
   FSCM(FSCM) = [CSECME, CSECMD, CSDCMD],
   WPFP(WPFP) = [WPFP0, WPFP1, WPFP2, WPFP3, WPFP4, WPFP5, WPFP6, WPFP7, WPFP8, WPFP9, WPFP10, WPFP11, WPFP12, WPFP13, WPFP14, WPFP15, WPFP16, WPFP17, WPFP18, WPFP19, WPFP20, WPFP21, WPFP22, WPFP23, WPFP24, WPFP25, WPFP26, WPFP27, WPFP28, WPFP29, WPFP30, WPFP31, WPFP32, WPFP33, WPFP34, WPFP35, WPFP36, WPFP37, WPFP38, WPFP39, WPFP40, WPFP41, WPFP42, WPFP43, WPFP44, WPFP45, WPFP46, WPFP47, WPFP48, WPFP49, WPFP50, WPFP51, WPFP52, WPFP53, WPFP54, WPFP55, WPFP56, WPFP57, WPFP58, WPFP59, WPFP60, WPFP61, WPFP62, WPFP63, WPFP64, WPFP65, WPFP66, WPFP67, WPFP68, WPFP69, WPFP70, WPFP71, WPFP72, WPFP73, WPFP74, WPFP75, WPFP76, WPFP77, WPFP78, WPFP79, WPFP80, WPFP81, WPFP82, WPFP83, WPFP84, WPFP85, WPFP86, WPFP87, WPFP88, WPFP89, WPFP90, WPFP91, WPFP92, WPFP93, WPFP94, WPFP95, WPFP96, WPFP97, WPFP98, WPFP99, WPFP100, WPFP101, WPFP102, WPFP103, WPFP104, WPFP105, WPFP106, WPFP107, WPFP108, WPFP109, WPFP110, WPFP111, WPFP112, WPFP113, WPFP114, WPFP115, WPFP116, WPFP117, WPFP118, WPFP119, WPFP120, WPFP121, WPFP122, WPFP123, WPFP124, WPFP125, WPFP126, WPFP127, WPFP128, WPFP129, WPFP130, WPFP131, WPFP132, WPFP133, WPFP134, WPFP135, WPFP136, WPFP137, WPFP138, WPFP139, WPFP140, WPFP141, WPFP142, WPFP143, WPFP144, WPFP145, WPFP146, WPFP147, WPFP148, WPFP149, WPFP150, WPFP151, WPFP152, WPFP153, WPFP154, WPFP155, WPFP156, WPFP157, WPFP158, WPFP159, WPFP160, WPFP161, WPFP162, WPFP163, WPFP164, WPFP165, WPFP166, WPFP167, WPFP168, WPFP169, WPFP170, WPFP171, WPFP172, WPFP173, WPFP174, WPFP175, WPFP176, WPFP177, WPFP178, WPFP179, WPFP180, WPFP181, WPFP182, WPFP183, WPFP184, WPFP185, WPFP186, WPFP187, WPFP188, WPFP189, WPFP190, WPFP191, WPFP192, WPFP193, WPFP194, WPFP195, WPFP196, WPFP197, WPFP198, WPFP199, WPFP200, WPFP201, WPFP202, WPFP203, WPFP204, WPFP205, WPFP206, WPFP207, WPFP208, WPFP209, WPFP210, WPFP211, WPFP212, WPFP213, WPFP214, WPFP215, WPFP216, WPFP217, WPFP218, WPFP219, WPFP220, WPFP221, WPFP222, WPFP223, WPFP224, WPFP225, WPFP226, WPFP227, WPFP228, WPFP229, WPFP230, WPFP231, WPFP232, WPFP233, WPFP234, WPFP235, WPFP236, WPFP237, WPFP238, WPFP239, WPFP240, WPFP241, WPFP242, WPFP243, WPFP244, WPFP245, WPFP246, WPFP247, WPFP248, WPFP249, WPFP250, WPFP251, WPFP252, WPFP253, WPFP254, WPFP255],
   WPDIS(WPDIS) = [WPEN, WPDIS],
   WPEND(WPEND) = [WPSTARTMEM, WPENDMEM],
   WPCFG(WPCFG) = [WPCFGEN, WPCFGDIS],
   T5GSEL(T5GSEL) = [T3G, T5G],
   CINASEL(CINASEL) = [RA5, DEFAULT],
   IOL1WAY(IOL1WAY) = [OFF, ON],
   LS48MHZ(LS48MHZ) = [SYSX1, SYSX2],
   MSSPMSK2(MSSPMSK2) = [MSK5, MSK7],
   MSSPMSK1(MSSPMSK1) = [MSK5, MSK7],
   WDTWIN(WDTWIN) = [PS75_0, PS50_0, PS37_5, PS25_0],
   WDTCLK(WDTCLK) = [SYS, SOSC, LPRC, FRC],
   WDTPS(WDTPS) = [1, 2, 4, 8, 16, 32, 64, 128, 256, 512, 1024, 2048, 4096, 8192, 16384, 32768],
   WDTEN(WDTEN) = [OFF, NOSLP, ON, SWDTDIS],
   WINDIS(WINDIS) = [WDTWIN, WDTSTD],
   WPSA(WPSA) = [32, 128],
   RETEN(RETEN) = [ON, OFF],
   VBTBOR(VBTBOR) = [OFF, ON],
   DSBOREN(DSBOREN) = [OFF, ON],
   DSBITEN(DSBITEN) = [OFF, ON],
   DSWDTPS(DSWDTPS) = [DSWDTPS0, DSWDTPS1, DSWDTPS2, DSWDTPS3, DSWDTPS4, DSWDTPS5, DSWDTPS6, DSWDTPS7, DSWDTPS8, DSWDTPS9, DSWDTPSA, DSWDTPSB, DSWDTPSC, DSWDTPSD, DSWDTPSE, DSWDTPSF, DSWDTPS10, DSWDTPS11, DSWDTPS12, DSWDTPS13, DSWDTPS14, DSWDTPS15, DSWDTPS16, DSWDTPS17, DSWDTPS18, DSWDTPS19, DSWDTPS1A, DSWDTPS1B, DSWDTPS1C, DSWDTPS1D, DSWDTPS1E, DSWDTPS1F],
   DSWDTEN(DSWDTEN) = [OFF, ON],
   DSWDTOSC(DSWDTOSC) = [SOSC, LPRC]

// default fuses...
config
   STVREN = ON,
   XINST = OFF,
   BOREN = ON,
   IESO = OFF,
   WDTPS = 128,
   WDTEN = OFF
