{
****************************************************************
*  Name    : 18F8620                                           *
*  Author  : David John Barker                                 *
*  Notice  : Copyright (c) 2015 Mecanique                      *
*          : All Rights Reserved                               *
*  Date    : 7/3/2015                                          *
****************************************************************
}

module SystemTypes

// system header...
#const _core = $0012                   // processor core
#const _ram_banks = $0F                // 15 RAM bank(s) used
#variable _maxaccess = $60             // access ram is 96 bytes
#variable _maxram = $0F00              // 3840 bytes of user RAM
#variable _maxrom = $010000            // 64 KB of program ROM
#const _eeprom = $0400                 // 1024 bytes of EEPROM
#const _eeprom_start = $F00000         // EEPROM start address
#const _ports = $09                    // 9 available ports
#const _no_porti = $01                 // no PORTI
#const _ccp = $05                      // 5 CCP module(s) available
#const _eccp = $00                     // ECCP module NOT supported
#const _mssp = $01                     // 1 MSSP module(s) available
#const _usart = $02                    // 2 USART(s) available
#const _adc = $10                      // 16 ADC channels available
#const _adres = $0A                    // 10 bit ADC resolution
#const _comparator = $02               // 2 comparator(s) available
#const _psp = $01                      // onboard Parallel Slave Port (PSP) available
#const _can = $00                      // onboard CAN is NOT supported
#const _usb = $00                      // USB is NOT supported
#const _ethernet = $00                 // onboard Ethernet is NOT supported
#const _flash_write = $01              // FLASH has write capability
#const _wdt_type = $00                 // WDT watchdog

// special function registers...
public system
   RCSTA2 as byte absolute $0F6B,
   TXSTA2 as byte absolute $0F6C,
   TXREG2 as byte absolute $0F6D,
   RCREG2 as byte absolute $0F6E,
   SPBRG2 as byte absolute $0F6F,
   CCP5CON as byte absolute $0F70,
   CCPR5 as byte absolute $0F71,
   CCPR5L as byte absolute $0F71,
   CCPR5H as byte absolute $0F72,
   CCP4CON as byte absolute $0F73,
   CCPR4 as byte absolute $0F74,
   CCPR4L as byte absolute $0F74,
   CCPR4H as byte absolute $0F75,
   T4CON as byte absolute $0F76,
   PR4 as byte absolute $0F77,
   TMR4 as byte absolute $0F78,
   LATA as byte absolute $0F89,
   LATB as byte absolute $0F8A,
   LATC as byte absolute $0F8B,
   LATD as byte absolute $0F8C,
   LATE as byte absolute $0F8D,
   LATF as byte absolute $0F8E,
   LATG as byte absolute $0F8F,
   LATH as byte absolute $0F90,
   LATJ as byte absolute $0F91,
   DDRA as byte absolute $0F92,
   TRISA as byte absolute $0F92,
   DDRB as byte absolute $0F93,
   TRISB as byte absolute $0F93,
   DDRC as byte absolute $0F94,
   TRISC as byte absolute $0F94,
   DDRD as byte absolute $0F95,
   TRISD as byte absolute $0F95,
   DDRE as byte absolute $0F96,
   TRISE as byte absolute $0F96,
   DDRF as byte absolute $0F97,
   TRISF as byte absolute $0F97,
   DDRG as byte absolute $0F98,
   TRISG as byte absolute $0F98,
   DDRH as byte absolute $0F99,
   TRISH as byte absolute $0F99,
   DDRJ as byte absolute $0F9A,
   TRISJ as byte absolute $0F9A,
   MEMCON as byte absolute $0F9C,
   PIE1 as byte absolute $0F9D,
   PIR1 as byte absolute $0F9E,
   IPR1 as byte absolute $0F9F,
   PIE2 as byte absolute $0FA0,
   PIR2 as byte absolute $0FA1,
   IPR2 as byte absolute $0FA2,
   PIE3 as byte absolute $0FA3,
   PIR3 as byte absolute $0FA4,
   IPR3 as byte absolute $0FA5,
   EECON1 as byte absolute $0FA6,
   EECON2 as byte absolute $0FA7,
   EEDATA as byte absolute $0FA8,
   EEADR as byte absolute $0FA9,
   EEADRH as byte absolute $0FAA,
   RCSTA as byte absolute $0FAB,
   RCSTA1 as byte absolute $0FAB,
   TXSTA as byte absolute $0FAC,
   TXSTA1 as byte absolute $0FAC,
   TXREG as byte absolute $0FAD,
   TXREG1 as byte absolute $0FAD,
   RCREG as byte absolute $0FAE,
   RCREG1 as byte absolute $0FAE,
   SPBRG as byte absolute $0FAF,
   SPBRG1 as byte absolute $0FAF,
   PSPCON as byte absolute $0FB0,
   T3CON as byte absolute $0FB1,
   TMR3 as byte absolute $0FB2,
   TMR3L as byte absolute $0FB2,
   TMR3H as byte absolute $0FB3,
   CMCON as byte absolute $0FB4,
   CVRCON as byte absolute $0FB5,
   CCP3CON as byte absolute $0FB7,
   CCPR3 as byte absolute $0FB8,
   CCPR3L as byte absolute $0FB8,
   CCPR3H as byte absolute $0FB9,
   CCP2CON as byte absolute $0FBA,
   CCPR2 as byte absolute $0FBB,
   CCPR2L as byte absolute $0FBB,
   CCPR2H as byte absolute $0FBC,
   CCP1CON as byte absolute $0FBD,
   CCPR1 as byte absolute $0FBE,
   CCPR1L as byte absolute $0FBE,
   CCPR1H as byte absolute $0FBF,
   ADCON2 as byte absolute $0FC0,
   ADCON1 as byte absolute $0FC1,
   ADCON0 as byte absolute $0FC2,
   ADRES as byte absolute $0FC3,
   ADRESL as byte absolute $0FC3,
   ADRESH as byte absolute $0FC4,
   SSPCON2 as byte absolute $0FC5,
   SSPCON1 as byte absolute $0FC6,
   SSPSTAT as byte absolute $0FC7,
   SSPADD as byte absolute $0FC8,
   SSPBUF as byte absolute $0FC9,
   T2CON as byte absolute $0FCA,
   PR2 as byte absolute $0FCB,
   TMR2 as byte absolute $0FCC,
   T1CON as byte absolute $0FCD,
   TMR1 as byte absolute $0FCE,
   TMR1L as byte absolute $0FCE,
   TMR1H as byte absolute $0FCF,
   RCON as byte absolute $0FD0,
   WDTCON as byte absolute $0FD1,
   LVDCON as byte absolute $0FD2,
   OSCCON as byte absolute $0FD3,
   T0CON as byte absolute $0FD5,
   TMR0 as byte absolute $0FD6,
   TMR0L as byte absolute $0FD6,
   TMR0H as byte absolute $0FD7,
   STATUS as byte absolute $0FD8,
   FSR2L as byte absolute $0FD9,
   FSR2H as byte absolute $0FDA,
   PLUSW2 as byte absolute $0FDB,
   PREINC2 as byte absolute $0FDC,
   POSTDEC2 as byte absolute $0FDD,
   POSTINC2 as byte absolute $0FDE,
   INDF2 as byte absolute $0FDF,
   BSR as byte absolute $0FE0,
   FSR1L as byte absolute $0FE1,
   FSR1H as byte absolute $0FE2,
   PLUSW1 as byte absolute $0FE3,
   PREINC1 as byte absolute $0FE4,
   POSTDEC1 as byte absolute $0FE5,
   POSTINC1 as byte absolute $0FE6,
   INDF1 as byte absolute $0FE7,
   WREG as byte absolute $0FE8,
   FSR0L as byte absolute $0FE9,
   FSR0H as byte absolute $0FEA,
   PLUSW0 as byte absolute $0FEB,
   PREINC0 as byte absolute $0FEC,
   POSTDEC0 as byte absolute $0FED,
   POSTINC0 as byte absolute $0FEE,
   INDF0 as byte absolute $0FEF,
   INTCON3 as byte absolute $0FF0,
   INTCON2 as byte absolute $0FF1,
   INTCON as byte absolute $0FF2,
   INTCON1 as byte absolute $0FF2,
   PRODL as byte absolute $0FF3,
   PRODH as byte absolute $0FF4,
   TABLAT as byte absolute $0FF5,
   TBLPTR as byte absolute $0FF6,
   TBLPTRL as byte absolute $0FF6,
   TBLPTRH as byte absolute $0FF7,
   TBLPTRU as byte absolute $0FF8,
   PC as byte absolute $0FF9,
   PCL as byte absolute $0FF9,
   PCLATH as byte absolute $0FFA,
   PCLATU as byte absolute $0FFB,
   STKPTR as byte absolute $0FFC,
   TOS as byte absolute $0FFD,
   TOSL as byte absolute $0FFD,
   TOSH as byte absolute $0FFE,
   TOSU as byte absolute $0FFF

// system ports...
public system port
   PORTA as byte absolute $0F80,
   PORTB as byte absolute $0F81,
   PORTC as byte absolute $0F82,
   PORTD as byte absolute $0F83,
   PORTE as byte absolute $0F84,
   PORTF as byte absolute $0F85,
   PORTG as byte absolute $0F86,
   PORTH as byte absolute $0F87,
   PORTJ as byte absolute $0F88

// alias...
public dim
   PROD as PRODL.AsWord,
   FSR0 as FSR0L.AsWord,
   FSR1 as FSR1L.AsWord,
   FSR2 as FSR2L.AsWord,
   TABLEPTR as TBLPTRL.AsWord

// configuration fuses...
public config
   OSC(OSC) = [LP, XT, HS, RC, EC, ECIO, HSPLL, RCIO],
   OSCS(OSCS) = [ON, OFF],
   PWRT(PWRT) = [ON, OFF],
   BOR(BOR) = [OFF, ON],
   BORV(BORV) = [45, 42, 27, 25],
   WDT(WDT) = [OFF, ON],
   WDTPS(WDTPS) = [1, 2, 4, 8, 16, 32, 64, 128],
   MODE(MODE) = [EM, MPB, MP, MC],
   WAIT(WAIT) = [ON, OFF],
   CCP2MUX(CCP2MUX) = [OFF, ON],
   STVR(STVR) = [OFF, ON],
   LVP(LVP) = [OFF, ON],
   DEBUG(DEBUG) = [ON, OFF],
   CP0(CP0) = [ON, OFF],
   CP1(CP1) = [ON, OFF],
   CP2(CP2) = [ON, OFF],
   CP3(CP3) = [ON, OFF],
   CPB(CPB) = [ON, OFF],
   CPD(CPD) = [ON, OFF],
   WRT0(WRT0) = [ON, OFF],
   WRT1(WRT1) = [ON, OFF],
   WRT2(WRT2) = [ON, OFF],
   WRT3(WRT3) = [ON, OFF],
   WRTC(WRTC) = [ON, OFF],
   WRTB(WRTB) = [ON, OFF],
   WRTD(WRTD) = [ON, OFF],
   EBTR0(EBTR0) = [ON, OFF],
   EBTR1(EBTR1) = [ON, OFF],
   EBTR2(EBTR2) = [ON, OFF],
   EBTR3(EBTR3) = [ON, OFF],
   EBTRB(EBTRB) = [ON, OFF]

// default fuses...
config
   OSC = HS,
   OSCS = OFF,
   PWRT = ON,
   BOR = ON,
   BORV = 25,
   WDT = OFF,
   WDTPS = 128,
   STVR = ON,
   LVP = OFF,
   DEBUG = OFF
