{
****************************************************************
*  Name    : 18F86J16                                          *
*  Author  : David John Barker                                 *
*  Notice  : Copyright (c) 2015 Mecanique                      *
*          : All Rights Reserved                               *
*  Date    : 7/3/2015                                          *
****************************************************************
}

module SystemTypes

// system header...
#const _core = $0012                   // processor core
#const _ram_banks = $10                // 16 RAM bank(s) used
#variable _maxaccess = $60             // access ram is 96 bytes
#variable _maxram = $0F40              // 3904 bytes of user RAM
#variable _maxrom = $017FF8            // 95 KB of program ROM
#const _eeprom = $0000                 // 0 bytes of EEPROM
#const _eeprom_start = $F00000         // EEPROM start address
#const _ports = $09                    // 9 available ports
#const _no_porti = $01                 // no PORTI
#const _ccp = $02                      // 2 CCP module(s) available
#const _eccp = $03                     // 3 ECCP module(s) available
#const _mssp = $02                     // 2 MSSP module(s) available
#const _usart = $02                    // 2 USART(s) available
#const _adc = $0F                      // 15 ADC channels available
#const _adres = $0A                    // 10 bit ADC resolution
#const _comparator = $02               // 2 comparator(s) available
#const _psp = $00                      // Parallel Slave Port (PSP) is NOT supported
#const _can = $00                      // onboard CAN is NOT supported
#const _usb = $00                      // USB is NOT supported
#const _ethernet = $00                 // onboard Ethernet is NOT supported
#const _flash_write = $01              // FLASH has write capability
#const _wdt_type = $01                 // WDTEN watchdog

// special function registers...
public system
   PMSTAT as byte absolute $0F5A,
   PMSTATL as byte absolute $0F5A,
   PMSTATH as byte absolute $0F5B,
   PMEL as byte absolute $0F5C,
   PMEN as byte absolute $0F5C,
   PMEH as byte absolute $0F5D,
   PMDIN2 as byte absolute $0F5E,
   PMDIN2L as byte absolute $0F5E,
   PMDIN2H as byte absolute $0F5F,
   PMDOUT2 as byte absolute $0F60,
   PMDOUT2L as byte absolute $0F60,
   PMDOUT2H as byte absolute $0F61,
   PMMODE as byte absolute $0F62,
   PMMODEL as byte absolute $0F62,
   PMMODEH as byte absolute $0F63,
   PMCON as byte absolute $0F64,
   PMCONL as byte absolute $0F64,
   PMCONH as byte absolute $0F65,
   PMDIN1 as byte absolute $0F66,
   PMDIN1L as byte absolute $0F66,
   PMDIN1H as byte absolute $0F67,
   PMADDR as byte absolute $0F68,
   PMADDRL as byte absolute $0F68,
   PMDOUT1 as byte absolute $0F68,
   PMDOUT1L as byte absolute $0F68,
   PMADDRH as byte absolute $0F69,
   PMDOUT1H as byte absolute $0F69,
   CMSTAT as byte absolute $0F6A,
   CMSTATUS as byte absolute $0F6A,
   SSP2CON2 as byte absolute $0F6B,
   SSP2CON1 as byte absolute $0F6C,
   SSP2STAT as byte absolute $0F6D,
   SSP2ADD as byte absolute $0F6E,
   SSP2MSK as byte absolute $0F6E,
   SSP2BUF as byte absolute $0F6F,
   CCP5CON as byte absolute $0F70,
   CCPR5 as byte absolute $0F71,
   CCPR5L as byte absolute $0F71,
   CCPR5H as byte absolute $0F72,
   CCP4CON as byte absolute $0F73,
   CCPR4 as byte absolute $0F74,
   CCPR4L as byte absolute $0F74,
   CCPR4H as byte absolute $0F75,
   T4CON as byte absolute $0F76,
   CVRCON as byte absolute $0F77,
   PR4 as byte absolute $0F77,
   TMR4 as byte absolute $0F78,
   T3CON as byte absolute $0F79,
   TMR3 as byte absolute $0F7A,
   TMR3L as byte absolute $0F7A,
   TMR3H as byte absolute $0F7B,
   BAUDCON2 as byte absolute $0F7C,
   SPBRGH2 as byte absolute $0F7D,
   BAUDCON as byte absolute $0F7E,
   BAUDCON1 as byte absolute $0F7E,
   SPBRGH1 as byte absolute $0F7F,
   LATA as byte absolute $0F89,
   LATB as byte absolute $0F8A,
   LATC as byte absolute $0F8B,
   LATD as byte absolute $0F8C,
   LATE as byte absolute $0F8D,
   LATF as byte absolute $0F8E,
   LATG as byte absolute $0F8F,
   LATH as byte absolute $0F90,
   LATJ as byte absolute $0F91,
   DDRA as byte absolute $0F92,
   TRISA as byte absolute $0F92,
   DDRB as byte absolute $0F93,
   TRISB as byte absolute $0F93,
   DDRC as byte absolute $0F94,
   TRISC as byte absolute $0F94,
   DDRD as byte absolute $0F95,
   TRISD as byte absolute $0F95,
   DDRE as byte absolute $0F96,
   TRISE as byte absolute $0F96,
   DDRF as byte absolute $0F97,
   TRISF as byte absolute $0F97,
   DDRG as byte absolute $0F98,
   TRISG as byte absolute $0F98,
   DDRH as byte absolute $0F99,
   TRISH as byte absolute $0F99,
   DDRJ as byte absolute $0F9A,
   TRISJ as byte absolute $0F9A,
   OSCTUNE as byte absolute $0F9B,
   RCSTA2 as byte absolute $0F9C,
   PIE1 as byte absolute $0F9D,
   PIR1 as byte absolute $0F9E,
   IPR1 as byte absolute $0F9F,
   PIE2 as byte absolute $0FA0,
   PIR2 as byte absolute $0FA1,
   IPR2 as byte absolute $0FA2,
   PIE3 as byte absolute $0FA3,
   PIR3 as byte absolute $0FA4,
   IPR3 as byte absolute $0FA5,
   EECON1 as byte absolute $0FA6,
   EECON2 as byte absolute $0FA7,
   TXSTA2 as byte absolute $0FA8,
   TXREG2 as byte absolute $0FA9,
   RCREG2 as byte absolute $0FAA,
   SPBRG2 as byte absolute $0FAB,
   RCSTA as byte absolute $0FAC,
   RCSTA1 as byte absolute $0FAC,
   TXSTA as byte absolute $0FAD,
   TXSTA1 as byte absolute $0FAD,
   TXREG as byte absolute $0FAE,
   TXREG1 as byte absolute $0FAE,
   RCREG as byte absolute $0FAF,
   RCREG1 as byte absolute $0FAF,
   SPBRG as byte absolute $0FB0,
   SPBRG1 as byte absolute $0FB0,
   CCP3CON as byte absolute $0FB1,
   ECCP3CON as byte absolute $0FB1,
   CCPR3 as byte absolute $0FB2,
   CCPR3L as byte absolute $0FB2,
   CCPR3H as byte absolute $0FB3,
   ECCP3DEL as byte absolute $0FB4,
   ECCP3AS as byte absolute $0FB5,
   CCP2CON as byte absolute $0FB6,
   ECCP2CON as byte absolute $0FB6,
   CCPR2 as byte absolute $0FB7,
   CCPR2L as byte absolute $0FB7,
   CCPR2H as byte absolute $0FB8,
   ECCP2DEL as byte absolute $0FB9,
   ECCP2AS as byte absolute $0FBA,
   CCP1CON as byte absolute $0FBB,
   ECCP1CON as byte absolute $0FBB,
   CCPR1 as byte absolute $0FBC,
   CCPR1L as byte absolute $0FBC,
   CCPR1H as byte absolute $0FBD,
   ECCP1DEL as byte absolute $0FBE,
   ECCP1AS as byte absolute $0FBF,
   WDTCON as byte absolute $0FC0,
   ADCON1 as byte absolute $0FC1,
   ANCON0 as byte absolute $0FC1,
   ADCON0 as byte absolute $0FC2,
   ANCON1 as byte absolute $0FC2,
   ADRES as byte absolute $0FC3,
   ADRESL as byte absolute $0FC3,
   ADRESH as byte absolute $0FC4,
   SSP1CON2 as byte absolute $0FC5,
   SSPCON2 as byte absolute $0FC5,
   SSP1CON1 as byte absolute $0FC6,
   SSPCON1 as byte absolute $0FC6,
   SSP1STAT as byte absolute $0FC7,
   SSPSTAT as byte absolute $0FC7,
   SSP1ADD as byte absolute $0FC8,
   SSP1MSK as byte absolute $0FC8,
   SSPADD as byte absolute $0FC8,
   SSP1BUF as byte absolute $0FC9,
   SSPBUF as byte absolute $0FC9,
   T2CON as byte absolute $0FCA,
   MEMCON as byte absolute $0FCB,
   PR2 as byte absolute $0FCB,
   PADCFG1 as byte absolute $0FCC,
   TMR2 as byte absolute $0FCC,
   ODCON3 as byte absolute $0FCD,
   T1CON as byte absolute $0FCD,
   ODCON2 as byte absolute $0FCE,
   TMR1 as byte absolute $0FCE,
   TMR1L as byte absolute $0FCE,
   ODCON1 as byte absolute $0FCF,
   TMR1H as byte absolute $0FCF,
   RCON as byte absolute $0FD0,
   CM2CON as byte absolute $0FD1,
   CM2CON1 as byte absolute $0FD1,
   CM1CON as byte absolute $0FD2,
   CM1CON1 as byte absolute $0FD2,
   OSCCON as byte absolute $0FD3,
   REFOCON as byte absolute $0FD3,
   T0CON as byte absolute $0FD5,
   TMR0 as byte absolute $0FD6,
   TMR0L as byte absolute $0FD6,
   TMR0H as byte absolute $0FD7,
   STATUS as byte absolute $0FD8,
   FSR2L as byte absolute $0FD9,
   FSR2H as byte absolute $0FDA,
   PLUSW2 as byte absolute $0FDB,
   PREINC2 as byte absolute $0FDC,
   POSTDEC2 as byte absolute $0FDD,
   POSTINC2 as byte absolute $0FDE,
   INDF2 as byte absolute $0FDF,
   BSR as byte absolute $0FE0,
   FSR1L as byte absolute $0FE1,
   FSR1H as byte absolute $0FE2,
   PLUSW1 as byte absolute $0FE3,
   PREINC1 as byte absolute $0FE4,
   POSTDEC1 as byte absolute $0FE5,
   POSTINC1 as byte absolute $0FE6,
   INDF1 as byte absolute $0FE7,
   WREG as byte absolute $0FE8,
   FSR0L as byte absolute $0FE9,
   FSR0H as byte absolute $0FEA,
   PLUSW0 as byte absolute $0FEB,
   PREINC0 as byte absolute $0FEC,
   POSTDEC0 as byte absolute $0FED,
   POSTINC0 as byte absolute $0FEE,
   INDF0 as byte absolute $0FEF,
   INTCON3 as byte absolute $0FF0,
   INTCON2 as byte absolute $0FF1,
   INTCON as byte absolute $0FF2,
   PRODL as byte absolute $0FF3,
   PRODH as byte absolute $0FF4,
   TABLAT as byte absolute $0FF5,
   TBLPTR as byte absolute $0FF6,
   TBLPTRL as byte absolute $0FF6,
   TBLPTRH as byte absolute $0FF7,
   TBLPTRU as byte absolute $0FF8,
   PC as byte absolute $0FF9,
   PCL as byte absolute $0FF9,
   PCLATH as byte absolute $0FFA,
   PCLATU as byte absolute $0FFB,
   STKPTR as byte absolute $0FFC,
   TOS as byte absolute $0FFD,
   TOSL as byte absolute $0FFD,
   TOSH as byte absolute $0FFE,
   TOSU as byte absolute $0FFF

// system ports...
public system port
   PORTA as byte absolute $0F80,
   PORTB as byte absolute $0F81,
   PORTC as byte absolute $0F82,
   PORTD as byte absolute $0F83,
   PORTE as byte absolute $0F84,
   PORTF as byte absolute $0F85,
   PORTG as byte absolute $0F86,
   PORTH as byte absolute $0F87,
   PORTJ as byte absolute $0F88

// alias...
public dim
   PROD as PRODL.AsWord,
   FSR0 as FSR0L.AsWord,
   FSR1 as FSR1L.AsWord,
   FSR2 as FSR2L.AsWord,
   TABLEPTR as TBLPTRL.AsWord

// configuration fuses...
public config
   WDTEN(WDTEN) = [OFF, ON],
   STVREN(STVREN) = [OFF, ON],
   XINST(XINST) = [OFF, ON],
   DEBUG(DEBUG) = [ON, OFF],
   CP0(CP0) = [ON, OFF],
   FOSC(FOSC) = [INTOSC, INTOSCO, INTOSCPLL, INTOSCPLLO, HS, HSPLL, EC, ECPLL],
   FCMEN(FCMEN) = [OFF, ON],
   IESO(IESO) = [OFF, ON],
   WDTPS(WDTPS) = [1, 2, 4, 8, 16, 32, 64, 128, 256, 512, 1024, 2048, 4096, 8192, 16384, 32768],
   EASHFT(EASHFT) = [OFF, ON],
   MODE(MODE) = [XM20, XM16, XM12, MM],
   BW(BW) = [8, 16],
   WAIT(WAIT) = [ON, OFF],
   CCP2MX(CCP2MX) = [ALTERNATE, DEFAULT],
   ECCPMX(ECCPMX) = [ALTERNATE, DEFAULT],
   PMPMX(PMPMX) = [ALTERNATE, DEFAULT],
   MSSPMSK(MSSPMSK) = [MSK5, MSK7]

// default fuses...
config
   WDTEN = OFF,
   STVREN = ON,
   XINST = OFF,
   DEBUG = OFF,
   FOSC = HS,
   FCMEN = OFF,
   IESO = OFF,
   WDTPS = 128
